Class: Google::Cloud::NetApp::V1::CacheConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/netapp/v1/volume.rb

Overview

Configuration of the cache volume.

Defined Under Namespace

Modules: CachePrePopulateState

Instance Attribute Summary collapse

Instance Attribute Details

#cache_pre_populate::Google::Cloud::NetApp::V1::CachePrePopulate

Returns Optional. Pre-populate cache volume with data from the origin volume.

Returns:



799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
# File 'proto_docs/google/cloud/netapp/v1/volume.rb', line 799

class CacheConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # State of the prepopulation job indicating how the prepopulation is
  # progressing.
  module CachePrePopulateState
    # Default unspecified state.
    CACHE_PRE_POPULATE_STATE_UNSPECIFIED = 0

    # State representing when the most recent create or update request did not
    # require a prepopulation job.
    NOT_NEEDED = 1

    # State representing when the most recent update request requested a
    # prepopulation job but it has not yet completed.
    IN_PROGRESS = 2

    # State representing when the most recent update request requested a
    # prepopulation job and it has completed successfully.
    COMPLETE = 3

    # State representing when the most recent update request requested a
    # prepopulation job but the prepopulate job failed.
    ERROR = 4
  end
end

#cache_pre_populate_state::Google::Cloud::NetApp::V1::CacheConfig::CachePrePopulateState (readonly)

Returns Output only. State of the prepopulation job indicating how the prepopulation is progressing.

Returns:



799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
# File 'proto_docs/google/cloud/netapp/v1/volume.rb', line 799

class CacheConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # State of the prepopulation job indicating how the prepopulation is
  # progressing.
  module CachePrePopulateState
    # Default unspecified state.
    CACHE_PRE_POPULATE_STATE_UNSPECIFIED = 0

    # State representing when the most recent create or update request did not
    # require a prepopulation job.
    NOT_NEEDED = 1

    # State representing when the most recent update request requested a
    # prepopulation job but it has not yet completed.
    IN_PROGRESS = 2

    # State representing when the most recent update request requested a
    # prepopulation job and it has completed successfully.
    COMPLETE = 3

    # State representing when the most recent update request requested a
    # prepopulation job but the prepopulate job failed.
    ERROR = 4
  end
end

#cifs_change_notify_enabled::Boolean

Returns Optional. Flag indicating whether a CIFS change notification is enabled for the FlexCache volume.

Returns:

  • (::Boolean)

    Optional. Flag indicating whether a CIFS change notification is enabled for the FlexCache volume.



799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
# File 'proto_docs/google/cloud/netapp/v1/volume.rb', line 799

class CacheConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # State of the prepopulation job indicating how the prepopulation is
  # progressing.
  module CachePrePopulateState
    # Default unspecified state.
    CACHE_PRE_POPULATE_STATE_UNSPECIFIED = 0

    # State representing when the most recent create or update request did not
    # require a prepopulation job.
    NOT_NEEDED = 1

    # State representing when the most recent update request requested a
    # prepopulation job but it has not yet completed.
    IN_PROGRESS = 2

    # State representing when the most recent update request requested a
    # prepopulation job and it has completed successfully.
    COMPLETE = 3

    # State representing when the most recent update request requested a
    # prepopulation job but the prepopulate job failed.
    ERROR = 4
  end
end

#writeback_enabled::Boolean

Returns Optional. Flag indicating whether writeback is enabled for the FlexCache volume.

Returns:

  • (::Boolean)

    Optional. Flag indicating whether writeback is enabled for the FlexCache volume.



799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
# File 'proto_docs/google/cloud/netapp/v1/volume.rb', line 799

class CacheConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # State of the prepopulation job indicating how the prepopulation is
  # progressing.
  module CachePrePopulateState
    # Default unspecified state.
    CACHE_PRE_POPULATE_STATE_UNSPECIFIED = 0

    # State representing when the most recent create or update request did not
    # require a prepopulation job.
    NOT_NEEDED = 1

    # State representing when the most recent update request requested a
    # prepopulation job but it has not yet completed.
    IN_PROGRESS = 2

    # State representing when the most recent update request requested a
    # prepopulation job and it has completed successfully.
    COMPLETE = 3

    # State representing when the most recent update request requested a
    # prepopulation job but the prepopulate job failed.
    ERROR = 4
  end
end