Module: Google::Cloud::NetApp::V1::CacheConfig::CachePrePopulateState

Defined in:
proto_docs/google/cloud/netapp/v1/volume.rb

Overview

State of the prepopulation job indicating how the prepopulation is progressing.

Constant Summary collapse

CACHE_PRE_POPULATE_STATE_UNSPECIFIED =

Default unspecified state.

0
NOT_NEEDED =

State representing when the most recent create or update request did not require a prepopulation job.

1
IN_PROGRESS =

State representing when the most recent update request requested a prepopulation job but it has not yet completed.

2
COMPLETE =

State representing when the most recent update request requested a prepopulation job and it has completed successfully.

3
ERROR =

State representing when the most recent update request requested a prepopulation job but the prepopulate job failed.

4