Class: Google::Cloud::NetApp::V1::CacheParameters

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/netapp/v1/volume.rb

Overview

Cache Parameters for the volume.

Defined Under Namespace

Modules: CacheState

Instance Attribute Summary collapse

Instance Attribute Details

#cache_config::Google::Cloud::NetApp::V1::CacheConfig

Returns Optional. Configuration of the cache volume.

Returns:



758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
774
775
776
777
778
779
780
781
# File 'proto_docs/google/cloud/netapp/v1/volume.rb', line 758

class CacheParameters
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # State of the cache volume indicating the peering status.
  module CacheState
    # Default unspecified state.
    CACHE_STATE_UNSPECIFIED = 0

    # State indicating waiting for cluster peering to be established.
    PENDING_CLUSTER_PEERING = 1

    # State indicating waiting for SVM peering to be established.
    PENDING_SVM_PEERING = 2

    # State indicating successful establishment of peering with origin
    # volumes's ONTAP cluster.
    PEERED = 3

    # Terminal state wherein peering with origin volume's ONTAP cluster
    # has failed.
    ERROR = 4
  end
end

#cache_state::Google::Cloud::NetApp::V1::CacheParameters::CacheState (readonly)

Returns Output only. State of the cache volume indicating the peering status.

Returns:



758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
774
775
776
777
778
779
780
781
# File 'proto_docs/google/cloud/netapp/v1/volume.rb', line 758

class CacheParameters
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # State of the cache volume indicating the peering status.
  module CacheState
    # Default unspecified state.
    CACHE_STATE_UNSPECIFIED = 0

    # State indicating waiting for cluster peering to be established.
    PENDING_CLUSTER_PEERING = 1

    # State indicating waiting for SVM peering to be established.
    PENDING_SVM_PEERING = 2

    # State indicating successful establishment of peering with origin
    # volumes's ONTAP cluster.
    PEERED = 3

    # Terminal state wherein peering with origin volume's ONTAP cluster
    # has failed.
    ERROR = 4
  end
end

#command::String (readonly)

Returns Output only. Copy-paste-able commands to be used on user's ONTAP to accept peering requests.

Returns:

  • (::String)

    Output only. Copy-paste-able commands to be used on user's ONTAP to accept peering requests.



758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
774
775
776
777
778
779
780
781
# File 'proto_docs/google/cloud/netapp/v1/volume.rb', line 758

class CacheParameters
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # State of the cache volume indicating the peering status.
  module CacheState
    # Default unspecified state.
    CACHE_STATE_UNSPECIFIED = 0

    # State indicating waiting for cluster peering to be established.
    PENDING_CLUSTER_PEERING = 1

    # State indicating waiting for SVM peering to be established.
    PENDING_SVM_PEERING = 2

    # State indicating successful establishment of peering with origin
    # volumes's ONTAP cluster.
    PEERED = 3

    # Terminal state wherein peering with origin volume's ONTAP cluster
    # has failed.
    ERROR = 4
  end
end

#enable_global_file_lock::Boolean

Returns Optional. Indicates whether the cache volume has global file lock enabled.

Returns:

  • (::Boolean)

    Optional. Indicates whether the cache volume has global file lock enabled.



758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
774
775
776
777
778
779
780
781
# File 'proto_docs/google/cloud/netapp/v1/volume.rb', line 758

class CacheParameters
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # State of the cache volume indicating the peering status.
  module CacheState
    # Default unspecified state.
    CACHE_STATE_UNSPECIFIED = 0

    # State indicating waiting for cluster peering to be established.
    PENDING_CLUSTER_PEERING = 1

    # State indicating waiting for SVM peering to be established.
    PENDING_SVM_PEERING = 2

    # State indicating successful establishment of peering with origin
    # volumes's ONTAP cluster.
    PEERED = 3

    # Terminal state wherein peering with origin volume's ONTAP cluster
    # has failed.
    ERROR = 4
  end
end

#passphrase::String (readonly)

Returns Output only. Temporary passphrase generated to accept cluster peering command.

Returns:

  • (::String)

    Output only. Temporary passphrase generated to accept cluster peering command.



758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
774
775
776
777
778
779
780
781
# File 'proto_docs/google/cloud/netapp/v1/volume.rb', line 758

class CacheParameters
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # State of the cache volume indicating the peering status.
  module CacheState
    # Default unspecified state.
    CACHE_STATE_UNSPECIFIED = 0

    # State indicating waiting for cluster peering to be established.
    PENDING_CLUSTER_PEERING = 1

    # State indicating waiting for SVM peering to be established.
    PENDING_SVM_PEERING = 2

    # State indicating successful establishment of peering with origin
    # volumes's ONTAP cluster.
    PEERED = 3

    # Terminal state wherein peering with origin volume's ONTAP cluster
    # has failed.
    ERROR = 4
  end
end

#peer_cluster_name::String

Returns Required. Name of the origin volume's ONTAP cluster.

Returns:

  • (::String)

    Required. Name of the origin volume's ONTAP cluster.



758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
774
775
776
777
778
779
780
781
# File 'proto_docs/google/cloud/netapp/v1/volume.rb', line 758

class CacheParameters
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # State of the cache volume indicating the peering status.
  module CacheState
    # Default unspecified state.
    CACHE_STATE_UNSPECIFIED = 0

    # State indicating waiting for cluster peering to be established.
    PENDING_CLUSTER_PEERING = 1

    # State indicating waiting for SVM peering to be established.
    PENDING_SVM_PEERING = 2

    # State indicating successful establishment of peering with origin
    # volumes's ONTAP cluster.
    PEERED = 3

    # Terminal state wherein peering with origin volume's ONTAP cluster
    # has failed.
    ERROR = 4
  end
end

#peer_ip_addresses::Array<::String>

Returns Required. List of IC LIF addresses of the origin volume's ONTAP cluster.

Returns:

  • (::Array<::String>)

    Required. List of IC LIF addresses of the origin volume's ONTAP cluster.



758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
774
775
776
777
778
779
780
781
# File 'proto_docs/google/cloud/netapp/v1/volume.rb', line 758

class CacheParameters
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # State of the cache volume indicating the peering status.
  module CacheState
    # Default unspecified state.
    CACHE_STATE_UNSPECIFIED = 0

    # State indicating waiting for cluster peering to be established.
    PENDING_CLUSTER_PEERING = 1

    # State indicating waiting for SVM peering to be established.
    PENDING_SVM_PEERING = 2

    # State indicating successful establishment of peering with origin
    # volumes's ONTAP cluster.
    PEERED = 3

    # Terminal state wherein peering with origin volume's ONTAP cluster
    # has failed.
    ERROR = 4
  end
end

#peer_svm_name::String

Returns Required. Name of the origin volume's SVM.

Returns:

  • (::String)

    Required. Name of the origin volume's SVM.



758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
774
775
776
777
778
779
780
781
# File 'proto_docs/google/cloud/netapp/v1/volume.rb', line 758

class CacheParameters
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # State of the cache volume indicating the peering status.
  module CacheState
    # Default unspecified state.
    CACHE_STATE_UNSPECIFIED = 0

    # State indicating waiting for cluster peering to be established.
    PENDING_CLUSTER_PEERING = 1

    # State indicating waiting for SVM peering to be established.
    PENDING_SVM_PEERING = 2

    # State indicating successful establishment of peering with origin
    # volumes's ONTAP cluster.
    PEERED = 3

    # Terminal state wherein peering with origin volume's ONTAP cluster
    # has failed.
    ERROR = 4
  end
end

#peer_volume_name::String

Returns Required. Name of the origin volume for the cache volume.

Returns:

  • (::String)

    Required. Name of the origin volume for the cache volume.



758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
774
775
776
777
778
779
780
781
# File 'proto_docs/google/cloud/netapp/v1/volume.rb', line 758

class CacheParameters
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # State of the cache volume indicating the peering status.
  module CacheState
    # Default unspecified state.
    CACHE_STATE_UNSPECIFIED = 0

    # State indicating waiting for cluster peering to be established.
    PENDING_CLUSTER_PEERING = 1

    # State indicating waiting for SVM peering to be established.
    PENDING_SVM_PEERING = 2

    # State indicating successful establishment of peering with origin
    # volumes's ONTAP cluster.
    PEERED = 3

    # Terminal state wherein peering with origin volume's ONTAP cluster
    # has failed.
    ERROR = 4
  end
end

#peering_command_expiry_time::Google::Protobuf::Timestamp

Returns Optional. Expiration time for the peering command to be executed on user's ONTAP.

Returns:



758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
774
775
776
777
778
779
780
781
# File 'proto_docs/google/cloud/netapp/v1/volume.rb', line 758

class CacheParameters
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # State of the cache volume indicating the peering status.
  module CacheState
    # Default unspecified state.
    CACHE_STATE_UNSPECIFIED = 0

    # State indicating waiting for cluster peering to be established.
    PENDING_CLUSTER_PEERING = 1

    # State indicating waiting for SVM peering to be established.
    PENDING_SVM_PEERING = 2

    # State indicating successful establishment of peering with origin
    # volumes's ONTAP cluster.
    PEERED = 3

    # Terminal state wherein peering with origin volume's ONTAP cluster
    # has failed.
    ERROR = 4
  end
end

#state_details::String (readonly)

Returns Output only. Detailed description of the current cache state.

Returns:

  • (::String)

    Output only. Detailed description of the current cache state.



758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
774
775
776
777
778
779
780
781
# File 'proto_docs/google/cloud/netapp/v1/volume.rb', line 758

class CacheParameters
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # State of the cache volume indicating the peering status.
  module CacheState
    # Default unspecified state.
    CACHE_STATE_UNSPECIFIED = 0

    # State indicating waiting for cluster peering to be established.
    PENDING_CLUSTER_PEERING = 1

    # State indicating waiting for SVM peering to be established.
    PENDING_SVM_PEERING = 2

    # State indicating successful establishment of peering with origin
    # volumes's ONTAP cluster.
    PEERED = 3

    # Terminal state wherein peering with origin volume's ONTAP cluster
    # has failed.
    ERROR = 4
  end
end