Module: Google::Cloud::NetApp::V1::CacheParameters::CacheState

Defined in:
proto_docs/google/cloud/netapp/v1/volume.rb

Overview

State of the cache volume indicating the peering status.

Constant Summary collapse

CACHE_STATE_UNSPECIFIED =

Default unspecified state.

0
PENDING_CLUSTER_PEERING =

State indicating waiting for cluster peering to be established.

1
PENDING_SVM_PEERING =

State indicating waiting for SVM peering to be established.

2
PEERED =

State indicating successful establishment of peering with origin volumes's ONTAP cluster.

3
ERROR =

Terminal state wherein peering with origin volume's ONTAP cluster has failed.

4