Class: Google::Cloud::NetApp::V1::CachePrePopulate

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/netapp/v1/volume.rb

Overview

Pre-populate cache volume with data from the origin volume.

Instance Attribute Summary collapse

Instance Attribute Details

#exclude_path_list::Array<::String>

Returns Optional. List of directory-paths to be excluded for pre-population for the FlexCache volume.

Returns:

  • (::Array<::String>)

    Optional. List of directory-paths to be excluded for pre-population for the FlexCache volume.



840
841
842
843
# File 'proto_docs/google/cloud/netapp/v1/volume.rb', line 840

class CachePrePopulate
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#path_list::Array<::String>

Returns Optional. List of directory-paths to be pre-populated for the FlexCache volume.

Returns:

  • (::Array<::String>)

    Optional. List of directory-paths to be pre-populated for the FlexCache volume.



840
841
842
843
# File 'proto_docs/google/cloud/netapp/v1/volume.rb', line 840

class CachePrePopulate
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#recursion::Boolean

Returns Optional. Flag indicating whether the directories listed with the path_list need to be recursively pre-populated.

Returns:

  • (::Boolean)

    Optional. Flag indicating whether the directories listed with the path_list need to be recursively pre-populated.



840
841
842
843
# File 'proto_docs/google/cloud/netapp/v1/volume.rb', line 840

class CachePrePopulate
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end