Class: Google::Cloud::NetApp::V1::EstablishVolumePeeringRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/netapp/v1/volume.rb

Overview

EstablishVolumePeeringRequest establishes cluster and svm peerings between the source and destination clusters.

Instance Attribute Summary collapse

Instance Attribute Details

#name::String

Returns Required. The volume resource name, in the format projects/{project_id}/locations/{location}/volumes/{volume_id}.

Returns:

  • (::String)

    Required. The volume resource name, in the format projects/{project_id}/locations/{location}/volumes/{volume_id}



929
930
931
932
# File 'proto_docs/google/cloud/netapp/v1/volume.rb', line 929

class EstablishVolumePeeringRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#peer_cluster_name::String

Returns Required. Name of the user's local source cluster to be peered with the destination cluster.

Returns:

  • (::String)

    Required. Name of the user's local source cluster to be peered with the destination cluster.



929
930
931
932
# File 'proto_docs/google/cloud/netapp/v1/volume.rb', line 929

class EstablishVolumePeeringRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#peer_ip_addresses::Array<::String>

Returns Optional. List of IPv4 ip addresses to be used for peering.

Returns:

  • (::Array<::String>)

    Optional. List of IPv4 ip addresses to be used for peering.



929
930
931
932
# File 'proto_docs/google/cloud/netapp/v1/volume.rb', line 929

class EstablishVolumePeeringRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#peer_svm_name::String

Returns Required. Name of the user's local source vserver svm to be peered with the destination vserver svm.

Returns:

  • (::String)

    Required. Name of the user's local source vserver svm to be peered with the destination vserver svm.



929
930
931
932
# File 'proto_docs/google/cloud/netapp/v1/volume.rb', line 929

class EstablishVolumePeeringRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#peer_volume_name::String

Returns Required. Name of the user's local source volume to be peered with the destination volume.

Returns:

  • (::String)

    Required. Name of the user's local source volume to be peered with the destination volume.



929
930
931
932
# File 'proto_docs/google/cloud/netapp/v1/volume.rb', line 929

class EstablishVolumePeeringRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end