Class: Google::Cloud::NetApp::V1::ExecuteOntapPostRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/netapp/v1/ontap.rb

Overview

Request message for ExecuteOntapPost API.

Instance Attribute Summary collapse

Instance Attribute Details

#body::Google::Protobuf::Struct

Returns Required. The raw JSON body of the request. The body should be in the format of the ONTAP resource. For example:

{
  "body": {
    "field1": "value1",
    "field2": "value2",
  }
}
```.

Returns:

  • (::Google::Protobuf::Struct)

    Required. The raw JSON body of the request. The body should be in the format of the ONTAP resource. For example:

    {
      "body": {
        "field1": "value1",
        "field2": "value2",
      }
    }
    


45
46
47
48
# File 'proto_docs/google/cloud/netapp/v1/ontap.rb', line 45

class ExecuteOntapPostRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#ontap_path::String

Returns Required. The resource path of the ONTAP resource. Format: projects/{project_number}/locations/{location_id}/storagePools/{storage_pool_id}/ontap/{ontap_resource_path}. For example: projects/123456789/locations/us-central1/storagePools/my-storage-pool/ontap/api/storage/volumes.

Returns:

  • (::String)

    Required. The resource path of the ONTAP resource. Format: projects/{project_number}/locations/{location_id}/storagePools/{storage_pool_id}/ontap/{ontap_resource_path}. For example: projects/123456789/locations/us-central1/storagePools/my-storage-pool/ontap/api/storage/volumes.



45
46
47
48
# File 'proto_docs/google/cloud/netapp/v1/ontap.rb', line 45

class ExecuteOntapPostRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end