Class: Google::Cloud::NetApp::V1::HostGroup

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/netapp/v1/host_group.rb

Overview

Host group is a collection of hosts that can be used for accessing a Block Volume.

Defined Under Namespace

Modules: State, Type Classes: LabelsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. Create time of the host group.

Returns:



147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
# File 'proto_docs/google/cloud/netapp/v1/host_group.rb', line 147

class HostGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Types of host group.
  module Type
    # Unspecified type for host group.
    TYPE_UNSPECIFIED = 0

    # iSCSI initiator host group.
    ISCSI_INITIATOR = 1
  end

  # Host group states.
  module State
    # Unspecified state for host group.
    STATE_UNSPECIFIED = 0

    # Host group is creating.
    CREATING = 1

    # Host group is ready.
    READY = 2

    # Host group is updating.
    UPDATING = 3

    # Host group is deleting.
    DELETING = 4

    # Host group is disabled.
    DISABLED = 5
  end
end

#description::String

Returns Optional. Description of the host group.

Returns:

  • (::String)

    Optional. Description of the host group.



147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
# File 'proto_docs/google/cloud/netapp/v1/host_group.rb', line 147

class HostGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Types of host group.
  module Type
    # Unspecified type for host group.
    TYPE_UNSPECIFIED = 0

    # iSCSI initiator host group.
    ISCSI_INITIATOR = 1
  end

  # Host group states.
  module State
    # Unspecified state for host group.
    STATE_UNSPECIFIED = 0

    # Host group is creating.
    CREATING = 1

    # Host group is ready.
    READY = 2

    # Host group is updating.
    UPDATING = 3

    # Host group is deleting.
    DELETING = 4

    # Host group is disabled.
    DISABLED = 5
  end
end

#hosts::Array<::String>

Returns Required. The list of hosts associated with the host group.

Returns:

  • (::Array<::String>)

    Required. The list of hosts associated with the host group.



147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
# File 'proto_docs/google/cloud/netapp/v1/host_group.rb', line 147

class HostGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Types of host group.
  module Type
    # Unspecified type for host group.
    TYPE_UNSPECIFIED = 0

    # iSCSI initiator host group.
    ISCSI_INITIATOR = 1
  end

  # Host group states.
  module State
    # Unspecified state for host group.
    STATE_UNSPECIFIED = 0

    # Host group is creating.
    CREATING = 1

    # Host group is ready.
    READY = 2

    # Host group is updating.
    UPDATING = 3

    # Host group is deleting.
    DELETING = 4

    # Host group is disabled.
    DISABLED = 5
  end
end

#labels::Google::Protobuf::Map{::String => ::String}

Returns Optional. Labels of the host group.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    Optional. Labels of the host group.



147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
# File 'proto_docs/google/cloud/netapp/v1/host_group.rb', line 147

class HostGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Types of host group.
  module Type
    # Unspecified type for host group.
    TYPE_UNSPECIFIED = 0

    # iSCSI initiator host group.
    ISCSI_INITIATOR = 1
  end

  # Host group states.
  module State
    # Unspecified state for host group.
    STATE_UNSPECIFIED = 0

    # Host group is creating.
    CREATING = 1

    # Host group is ready.
    READY = 2

    # Host group is updating.
    UPDATING = 3

    # Host group is deleting.
    DELETING = 4

    # Host group is disabled.
    DISABLED = 5
  end
end

#name::String

Returns Identifier. The resource name of the host group. Format: projects/{project_number}/locations/{location_id}/hostGroups/{host_group_id}.

Returns:

  • (::String)

    Identifier. The resource name of the host group. Format: projects/{project_number}/locations/{location_id}/hostGroups/{host_group_id}.



147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
# File 'proto_docs/google/cloud/netapp/v1/host_group.rb', line 147

class HostGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Types of host group.
  module Type
    # Unspecified type for host group.
    TYPE_UNSPECIFIED = 0

    # iSCSI initiator host group.
    ISCSI_INITIATOR = 1
  end

  # Host group states.
  module State
    # Unspecified state for host group.
    STATE_UNSPECIFIED = 0

    # Host group is creating.
    CREATING = 1

    # Host group is ready.
    READY = 2

    # Host group is updating.
    UPDATING = 3

    # Host group is deleting.
    DELETING = 4

    # Host group is disabled.
    DISABLED = 5
  end
end

#os_type::Google::Cloud::NetApp::V1::OsType

Returns Required. The OS type of the host group. It indicates the type of operating system used by all of the hosts in the HostGroup. All hosts in a HostGroup must be of the same OS type. This can be set only when creating a HostGroup.

Returns:

  • (::Google::Cloud::NetApp::V1::OsType)

    Required. The OS type of the host group. It indicates the type of operating system used by all of the hosts in the HostGroup. All hosts in a HostGroup must be of the same OS type. This can be set only when creating a HostGroup.



147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
# File 'proto_docs/google/cloud/netapp/v1/host_group.rb', line 147

class HostGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Types of host group.
  module Type
    # Unspecified type for host group.
    TYPE_UNSPECIFIED = 0

    # iSCSI initiator host group.
    ISCSI_INITIATOR = 1
  end

  # Host group states.
  module State
    # Unspecified state for host group.
    STATE_UNSPECIFIED = 0

    # Host group is creating.
    CREATING = 1

    # Host group is ready.
    READY = 2

    # Host group is updating.
    UPDATING = 3

    # Host group is deleting.
    DELETING = 4

    # Host group is disabled.
    DISABLED = 5
  end
end

#state::Google::Cloud::NetApp::V1::HostGroup::State (readonly)

Returns Output only. State of the host group.

Returns:



147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
# File 'proto_docs/google/cloud/netapp/v1/host_group.rb', line 147

class HostGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Types of host group.
  module Type
    # Unspecified type for host group.
    TYPE_UNSPECIFIED = 0

    # iSCSI initiator host group.
    ISCSI_INITIATOR = 1
  end

  # Host group states.
  module State
    # Unspecified state for host group.
    STATE_UNSPECIFIED = 0

    # Host group is creating.
    CREATING = 1

    # Host group is ready.
    READY = 2

    # Host group is updating.
    UPDATING = 3

    # Host group is deleting.
    DELETING = 4

    # Host group is disabled.
    DISABLED = 5
  end
end

#type::Google::Cloud::NetApp::V1::HostGroup::Type

Returns Required. Type of the host group.

Returns:



147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
# File 'proto_docs/google/cloud/netapp/v1/host_group.rb', line 147

class HostGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Types of host group.
  module Type
    # Unspecified type for host group.
    TYPE_UNSPECIFIED = 0

    # iSCSI initiator host group.
    ISCSI_INITIATOR = 1
  end

  # Host group states.
  module State
    # Unspecified state for host group.
    STATE_UNSPECIFIED = 0

    # Host group is creating.
    CREATING = 1

    # Host group is ready.
    READY = 2

    # Host group is updating.
    UPDATING = 3

    # Host group is deleting.
    DELETING = 4

    # Host group is disabled.
    DISABLED = 5
  end
end