Class: Google::Cloud::NetApp::V1::LargeCapacityConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/netapp/v1/volume.rb

Overview

Configuration for a Large Capacity Volume. A Large Capacity Volume supports sizes ranging from 4.8 TiB to 20 PiB, it is composed of multiple internal constituents, and must be created in a large capacity pool.

Instance Attribute Summary collapse

Instance Attribute Details

#constituent_count::Integer

Returns Optional. The number of internal constituents (e.g., FlexVols) for this large volume. The minimum number of constituents is 2.

Returns:

  • (::Integer)

    Optional. The number of internal constituents (e.g., FlexVols) for this large volume. The minimum number of constituents is 2.



364
365
366
367
# File 'proto_docs/google/cloud/netapp/v1/volume.rb', line 364

class LargeCapacityConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end