Class: Google::Cloud::NetApp::V1::ListHostGroupsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/netapp/v1/host_group.rb

Overview

ListHostGroupsRequest for listing host groups.

Instance Attribute Summary collapse

Instance Attribute Details

#filter::String

Returns Optional. Filter to apply to the request.

Returns:

  • (::String)

    Optional. Filter to apply to the request.



41
42
43
44
# File 'proto_docs/google/cloud/netapp/v1/host_group.rb', line 41

class ListHostGroupsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#order_by::String

Returns Optional. Hint for how to order the results.

Returns:

  • (::String)

    Optional. Hint for how to order the results



41
42
43
44
# File 'proto_docs/google/cloud/netapp/v1/host_group.rb', line 41

class ListHostGroupsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_size::Integer

Returns Optional. Requested page size. Server may return fewer items than requested. If unspecified, the server will pick an appropriate default.

Returns:

  • (::Integer)

    Optional. Requested page size. Server may return fewer items than requested. If unspecified, the server will pick an appropriate default.



41
42
43
44
# File 'proto_docs/google/cloud/netapp/v1/host_group.rb', line 41

class ListHostGroupsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Optional. A token identifying a page of results the server should return.

Returns:

  • (::String)

    Optional. A token identifying a page of results the server should return.



41
42
43
44
# File 'proto_docs/google/cloud/netapp/v1/host_group.rb', line 41

class ListHostGroupsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. Parent value for ListHostGroupsRequest.

Returns:

  • (::String)

    Required. Parent value for ListHostGroupsRequest



41
42
43
44
# File 'proto_docs/google/cloud/netapp/v1/host_group.rb', line 41

class ListHostGroupsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end