Class: Google::Cloud::NetApp::V1::ListHostGroupsResponse
- Inherits:
-
Object
- Object
- Google::Cloud::NetApp::V1::ListHostGroupsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/netapp/v1/host_group.rb
Overview
ListHostGroupsResponse is the response to a ListHostGroupsRequest.
Instance Attribute Summary collapse
-
#host_groups ⇒ ::Array<::Google::Cloud::NetApp::V1::HostGroup>
The list of host groups.
-
#next_page_token ⇒ ::String
A token identifying a page of results the server should return.
-
#unreachable ⇒ ::Array<::String>
Locations that could not be reached.
Instance Attribute Details
#host_groups ⇒ ::Array<::Google::Cloud::NetApp::V1::HostGroup>
Returns The list of host groups.
56 57 58 59 |
# File 'proto_docs/google/cloud/netapp/v1/host_group.rb', line 56 class ListHostGroupsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#next_page_token ⇒ ::String
Returns A token identifying a page of results the server should return.
56 57 58 59 |
# File 'proto_docs/google/cloud/netapp/v1/host_group.rb', line 56 class ListHostGroupsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#unreachable ⇒ ::Array<::String>
Returns Locations that could not be reached.
56 57 58 59 |
# File 'proto_docs/google/cloud/netapp/v1/host_group.rb', line 56 class ListHostGroupsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |