Class: Google::Cloud::NetApp::V1::SimpleExportPolicyRule

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/netapp/v1/volume.rb

Overview

An export policy rule describing various export options.

Defined Under Namespace

Modules: SquashMode

Instance Attribute Summary collapse

Instance Attribute Details

#access_type::Google::Cloud::NetApp::V1::AccessType

Returns Access type (ReadWrite, ReadOnly, None).

Returns:



436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
# File 'proto_docs/google/cloud/netapp/v1/volume.rb', line 436

class SimpleExportPolicyRule
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # `SquashMode` defines how remote user privileges are restricted when
  # accessing an NFS export. It controls how user identities (like root) are
  # mapped to anonymous users to limit access and enforce security.
  module SquashMode
    # Defaults to `NO_ROOT_SQUASH`.
    SQUASH_MODE_UNSPECIFIED = 0

    # The root user (UID 0) retains full access. Other users are
    # unaffected.
    NO_ROOT_SQUASH = 1

    # The root user (UID 0) is squashed to anonymous user ID. Other users are
    # unaffected.
    ROOT_SQUASH = 2

    # All users are squashed to anonymous user ID.
    ALL_SQUASH = 3
  end
end

#allowed_clients::String

Returns Comma separated list of allowed clients IP addresses.

Returns:

  • (::String)

    Comma separated list of allowed clients IP addresses



436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
# File 'proto_docs/google/cloud/netapp/v1/volume.rb', line 436

class SimpleExportPolicyRule
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # `SquashMode` defines how remote user privileges are restricted when
  # accessing an NFS export. It controls how user identities (like root) are
  # mapped to anonymous users to limit access and enforce security.
  module SquashMode
    # Defaults to `NO_ROOT_SQUASH`.
    SQUASH_MODE_UNSPECIFIED = 0

    # The root user (UID 0) retains full access. Other users are
    # unaffected.
    NO_ROOT_SQUASH = 1

    # The root user (UID 0) is squashed to anonymous user ID. Other users are
    # unaffected.
    ROOT_SQUASH = 2

    # All users are squashed to anonymous user ID.
    ALL_SQUASH = 3
  end
end

#anon_uid::Integer

Returns Optional. An integer representing the anonymous user ID. Range is 0 to 4294967295. Required when squash_mode is ROOT_SQUASH or ALL_SQUASH.

Returns:

  • (::Integer)

    Optional. An integer representing the anonymous user ID. Range is 0 to 4294967295. Required when squash_mode is ROOT_SQUASH or ALL_SQUASH.



436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
# File 'proto_docs/google/cloud/netapp/v1/volume.rb', line 436

class SimpleExportPolicyRule
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # `SquashMode` defines how remote user privileges are restricted when
  # accessing an NFS export. It controls how user identities (like root) are
  # mapped to anonymous users to limit access and enforce security.
  module SquashMode
    # Defaults to `NO_ROOT_SQUASH`.
    SQUASH_MODE_UNSPECIFIED = 0

    # The root user (UID 0) retains full access. Other users are
    # unaffected.
    NO_ROOT_SQUASH = 1

    # The root user (UID 0) is squashed to anonymous user ID. Other users are
    # unaffected.
    ROOT_SQUASH = 2

    # All users are squashed to anonymous user ID.
    ALL_SQUASH = 3
  end
end

#has_root_access::String

Returns Whether Unix root access will be granted.

Returns:

  • (::String)

    Whether Unix root access will be granted.



436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
# File 'proto_docs/google/cloud/netapp/v1/volume.rb', line 436

class SimpleExportPolicyRule
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # `SquashMode` defines how remote user privileges are restricted when
  # accessing an NFS export. It controls how user identities (like root) are
  # mapped to anonymous users to limit access and enforce security.
  module SquashMode
    # Defaults to `NO_ROOT_SQUASH`.
    SQUASH_MODE_UNSPECIFIED = 0

    # The root user (UID 0) retains full access. Other users are
    # unaffected.
    NO_ROOT_SQUASH = 1

    # The root user (UID 0) is squashed to anonymous user ID. Other users are
    # unaffected.
    ROOT_SQUASH = 2

    # All users are squashed to anonymous user ID.
    ALL_SQUASH = 3
  end
end

#kerberos_5_read_only::Boolean

Returns If enabled (true) the rule defines a read only access for clients matching the 'allowedClients' specification. It enables nfs clients to mount using 'authentication' kerberos security mode.

Returns:

  • (::Boolean)

    If enabled (true) the rule defines a read only access for clients matching the 'allowedClients' specification. It enables nfs clients to mount using 'authentication' kerberos security mode.



436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
# File 'proto_docs/google/cloud/netapp/v1/volume.rb', line 436

class SimpleExportPolicyRule
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # `SquashMode` defines how remote user privileges are restricted when
  # accessing an NFS export. It controls how user identities (like root) are
  # mapped to anonymous users to limit access and enforce security.
  module SquashMode
    # Defaults to `NO_ROOT_SQUASH`.
    SQUASH_MODE_UNSPECIFIED = 0

    # The root user (UID 0) retains full access. Other users are
    # unaffected.
    NO_ROOT_SQUASH = 1

    # The root user (UID 0) is squashed to anonymous user ID. Other users are
    # unaffected.
    ROOT_SQUASH = 2

    # All users are squashed to anonymous user ID.
    ALL_SQUASH = 3
  end
end

#kerberos_5_read_write::Boolean

Returns If enabled (true) the rule defines read and write access for clients matching the 'allowedClients' specification. It enables nfs clients to mount using 'authentication' kerberos security mode. The 'kerberos5ReadOnly' value be ignored if this is enabled.

Returns:

  • (::Boolean)

    If enabled (true) the rule defines read and write access for clients matching the 'allowedClients' specification. It enables nfs clients to mount using 'authentication' kerberos security mode. The 'kerberos5ReadOnly' value be ignored if this is enabled.



436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
# File 'proto_docs/google/cloud/netapp/v1/volume.rb', line 436

class SimpleExportPolicyRule
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # `SquashMode` defines how remote user privileges are restricted when
  # accessing an NFS export. It controls how user identities (like root) are
  # mapped to anonymous users to limit access and enforce security.
  module SquashMode
    # Defaults to `NO_ROOT_SQUASH`.
    SQUASH_MODE_UNSPECIFIED = 0

    # The root user (UID 0) retains full access. Other users are
    # unaffected.
    NO_ROOT_SQUASH = 1

    # The root user (UID 0) is squashed to anonymous user ID. Other users are
    # unaffected.
    ROOT_SQUASH = 2

    # All users are squashed to anonymous user ID.
    ALL_SQUASH = 3
  end
end

#kerberos_5i_read_only::Boolean

Returns If enabled (true) the rule defines a read only access for clients matching the 'allowedClients' specification. It enables nfs clients to mount using 'integrity' kerberos security mode.

Returns:

  • (::Boolean)

    If enabled (true) the rule defines a read only access for clients matching the 'allowedClients' specification. It enables nfs clients to mount using 'integrity' kerberos security mode.



436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
# File 'proto_docs/google/cloud/netapp/v1/volume.rb', line 436

class SimpleExportPolicyRule
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # `SquashMode` defines how remote user privileges are restricted when
  # accessing an NFS export. It controls how user identities (like root) are
  # mapped to anonymous users to limit access and enforce security.
  module SquashMode
    # Defaults to `NO_ROOT_SQUASH`.
    SQUASH_MODE_UNSPECIFIED = 0

    # The root user (UID 0) retains full access. Other users are
    # unaffected.
    NO_ROOT_SQUASH = 1

    # The root user (UID 0) is squashed to anonymous user ID. Other users are
    # unaffected.
    ROOT_SQUASH = 2

    # All users are squashed to anonymous user ID.
    ALL_SQUASH = 3
  end
end

#kerberos_5i_read_write::Boolean

Returns If enabled (true) the rule defines read and write access for clients matching the 'allowedClients' specification. It enables nfs clients to mount using 'integrity' kerberos security mode. The 'kerberos5iReadOnly' value be ignored if this is enabled.

Returns:

  • (::Boolean)

    If enabled (true) the rule defines read and write access for clients matching the 'allowedClients' specification. It enables nfs clients to mount using 'integrity' kerberos security mode. The 'kerberos5iReadOnly' value be ignored if this is enabled.



436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
# File 'proto_docs/google/cloud/netapp/v1/volume.rb', line 436

class SimpleExportPolicyRule
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # `SquashMode` defines how remote user privileges are restricted when
  # accessing an NFS export. It controls how user identities (like root) are
  # mapped to anonymous users to limit access and enforce security.
  module SquashMode
    # Defaults to `NO_ROOT_SQUASH`.
    SQUASH_MODE_UNSPECIFIED = 0

    # The root user (UID 0) retains full access. Other users are
    # unaffected.
    NO_ROOT_SQUASH = 1

    # The root user (UID 0) is squashed to anonymous user ID. Other users are
    # unaffected.
    ROOT_SQUASH = 2

    # All users are squashed to anonymous user ID.
    ALL_SQUASH = 3
  end
end

#kerberos_5p_read_only::Boolean

Returns If enabled (true) the rule defines a read only access for clients matching the 'allowedClients' specification. It enables nfs clients to mount using 'privacy' kerberos security mode.

Returns:

  • (::Boolean)

    If enabled (true) the rule defines a read only access for clients matching the 'allowedClients' specification. It enables nfs clients to mount using 'privacy' kerberos security mode.



436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
# File 'proto_docs/google/cloud/netapp/v1/volume.rb', line 436

class SimpleExportPolicyRule
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # `SquashMode` defines how remote user privileges are restricted when
  # accessing an NFS export. It controls how user identities (like root) are
  # mapped to anonymous users to limit access and enforce security.
  module SquashMode
    # Defaults to `NO_ROOT_SQUASH`.
    SQUASH_MODE_UNSPECIFIED = 0

    # The root user (UID 0) retains full access. Other users are
    # unaffected.
    NO_ROOT_SQUASH = 1

    # The root user (UID 0) is squashed to anonymous user ID. Other users are
    # unaffected.
    ROOT_SQUASH = 2

    # All users are squashed to anonymous user ID.
    ALL_SQUASH = 3
  end
end

#kerberos_5p_read_write::Boolean

Returns If enabled (true) the rule defines read and write access for clients matching the 'allowedClients' specification. It enables nfs clients to mount using 'privacy' kerberos security mode. The 'kerberos5pReadOnly' value be ignored if this is enabled.

Returns:

  • (::Boolean)

    If enabled (true) the rule defines read and write access for clients matching the 'allowedClients' specification. It enables nfs clients to mount using 'privacy' kerberos security mode. The 'kerberos5pReadOnly' value be ignored if this is enabled.



436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
# File 'proto_docs/google/cloud/netapp/v1/volume.rb', line 436

class SimpleExportPolicyRule
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # `SquashMode` defines how remote user privileges are restricted when
  # accessing an NFS export. It controls how user identities (like root) are
  # mapped to anonymous users to limit access and enforce security.
  module SquashMode
    # Defaults to `NO_ROOT_SQUASH`.
    SQUASH_MODE_UNSPECIFIED = 0

    # The root user (UID 0) retains full access. Other users are
    # unaffected.
    NO_ROOT_SQUASH = 1

    # The root user (UID 0) is squashed to anonymous user ID. Other users are
    # unaffected.
    ROOT_SQUASH = 2

    # All users are squashed to anonymous user ID.
    ALL_SQUASH = 3
  end
end

#nfsv3::Boolean

Returns NFS V3 protocol.

Returns:

  • (::Boolean)

    NFS V3 protocol.



436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
# File 'proto_docs/google/cloud/netapp/v1/volume.rb', line 436

class SimpleExportPolicyRule
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # `SquashMode` defines how remote user privileges are restricted when
  # accessing an NFS export. It controls how user identities (like root) are
  # mapped to anonymous users to limit access and enforce security.
  module SquashMode
    # Defaults to `NO_ROOT_SQUASH`.
    SQUASH_MODE_UNSPECIFIED = 0

    # The root user (UID 0) retains full access. Other users are
    # unaffected.
    NO_ROOT_SQUASH = 1

    # The root user (UID 0) is squashed to anonymous user ID. Other users are
    # unaffected.
    ROOT_SQUASH = 2

    # All users are squashed to anonymous user ID.
    ALL_SQUASH = 3
  end
end

#nfsv4::Boolean

Returns NFS V4 protocol.

Returns:

  • (::Boolean)

    NFS V4 protocol.



436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
# File 'proto_docs/google/cloud/netapp/v1/volume.rb', line 436

class SimpleExportPolicyRule
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # `SquashMode` defines how remote user privileges are restricted when
  # accessing an NFS export. It controls how user identities (like root) are
  # mapped to anonymous users to limit access and enforce security.
  module SquashMode
    # Defaults to `NO_ROOT_SQUASH`.
    SQUASH_MODE_UNSPECIFIED = 0

    # The root user (UID 0) retains full access. Other users are
    # unaffected.
    NO_ROOT_SQUASH = 1

    # The root user (UID 0) is squashed to anonymous user ID. Other users are
    # unaffected.
    ROOT_SQUASH = 2

    # All users are squashed to anonymous user ID.
    ALL_SQUASH = 3
  end
end

#squash_mode::Google::Cloud::NetApp::V1::SimpleExportPolicyRule::SquashMode

Returns Optional. Defines how user identity squashing is applied for this export rule. This field is the preferred way to configure squashing behavior and takes precedence over has_root_access if both are provided.

Returns:



436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
# File 'proto_docs/google/cloud/netapp/v1/volume.rb', line 436

class SimpleExportPolicyRule
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # `SquashMode` defines how remote user privileges are restricted when
  # accessing an NFS export. It controls how user identities (like root) are
  # mapped to anonymous users to limit access and enforce security.
  module SquashMode
    # Defaults to `NO_ROOT_SQUASH`.
    SQUASH_MODE_UNSPECIFIED = 0

    # The root user (UID 0) retains full access. Other users are
    # unaffected.
    NO_ROOT_SQUASH = 1

    # The root user (UID 0) is squashed to anonymous user ID. Other users are
    # unaffected.
    ROOT_SQUASH = 2

    # All users are squashed to anonymous user ID.
    ALL_SQUASH = 3
  end
end