Module: Google::Cloud::NetApp::V1::SimpleExportPolicyRule::SquashMode

Defined in:
proto_docs/google/cloud/netapp/v1/volume.rb

Overview

SquashMode defines how remote user privileges are restricted when accessing an NFS export. It controls how user identities (like root) are mapped to anonymous users to limit access and enforce security.

Constant Summary collapse

SQUASH_MODE_UNSPECIFIED =

Defaults to NO_ROOT_SQUASH.

0
NO_ROOT_SQUASH =

The root user (UID 0) retains full access. Other users are unaffected.

1
ROOT_SQUASH =

The root user (UID 0) is squashed to anonymous user ID. Other users are unaffected.

2
ALL_SQUASH =

All users are squashed to anonymous user ID.

3