Class: Google::Cloud::NetApp::V1::UpdateHostGroupRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/netapp/v1/host_group.rb

Overview

UpdateHostGroupRequest for updating a host group.

Instance Attribute Summary collapse

Instance Attribute Details

#host_group::Google::Cloud::NetApp::V1::HostGroup

Returns Required. The host group to update. The host group's name field is used to identify the host group. Format: projects/{project_number}/locations/{location_id}/hostGroups/{host_group_id}.

Returns:

  • (::Google::Cloud::NetApp::V1::HostGroup)

    Required. The host group to update. The host group's name field is used to identify the host group. Format: projects/{project_number}/locations/{location_id}/hostGroups/{host_group_id}.



100
101
102
103
# File 'proto_docs/google/cloud/netapp/v1/host_group.rb', line 100

class UpdateHostGroupRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#update_mask::Google::Protobuf::FieldMask

Returns Optional. The list of fields to update.

Returns:



100
101
102
103
# File 'proto_docs/google/cloud/netapp/v1/host_group.rb', line 100

class UpdateHostGroupRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end