Class: Google::Cloud::NetApp::V1::Volume::CloneDetails

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/netapp/v1/volume.rb

Overview

Details about a clone volume.

Instance Attribute Summary collapse

Instance Attribute Details

#shared_space_gib::Integer (readonly)

Returns Output only. Shared space in GiB. Determined at volume creation time based on size of source snapshot.

Returns:

  • (::Integer)

    Output only. Shared space in GiB. Determined at volume creation time based on size of source snapshot.



307
308
309
310
# File 'proto_docs/google/cloud/netapp/v1/volume.rb', line 307

class CloneDetails
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#source_snapshot::String (readonly)

Returns Output only. Specifies the full resource name of the source snapshot from which this volume was cloned. Format: projects/{project}/locations/{location}/volumes/{volume}/snapshots/{snapshot}.

Returns:

  • (::String)

    Output only. Specifies the full resource name of the source snapshot from which this volume was cloned. Format: projects/{project}/locations/{location}/volumes/{volume}/snapshots/{snapshot}



307
308
309
310
# File 'proto_docs/google/cloud/netapp/v1/volume.rb', line 307

class CloneDetails
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#source_volume::String (readonly)

Returns Output only. Full name of the source volume resource. Format: projects/{project}/locations/{location}/volumes/{volume}.

Returns:

  • (::String)

    Output only. Full name of the source volume resource. Format: projects/{project}/locations/{location}/volumes/{volume}



307
308
309
310
# File 'proto_docs/google/cloud/netapp/v1/volume.rb', line 307

class CloneDetails
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end