Class: Google::Cloud::NetApp::V1::BackupVault
- Inherits:
-
Object
- Object
- Google::Cloud::NetApp::V1::BackupVault
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/netapp/v1/backup_vault.rb
Overview
A NetApp BackupVault.
Defined Under Namespace
Modules: BackupVaultType, EncryptionState, State Classes: BackupRetentionPolicy, LabelsEntry
Instance Attribute Summary collapse
-
#backup_region ⇒ ::String
Optional.
-
#backup_retention_policy ⇒ ::Google::Cloud::NetApp::V1::BackupVault::BackupRetentionPolicy
Optional.
-
#backup_vault_type ⇒ ::Google::Cloud::NetApp::V1::BackupVault::BackupVaultType
Optional.
-
#backups_crypto_key_version ⇒ ::String
readonly
Output only.
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#description ⇒ ::String
Description of the backup vault.
-
#destination_backup_vault ⇒ ::String
readonly
Output only.
-
#encryption_state ⇒ ::Google::Cloud::NetApp::V1::BackupVault::EncryptionState
readonly
Output only.
-
#kms_config ⇒ ::String
Optional.
-
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Resource labels to represent user provided metadata.
-
#name ⇒ ::String
Identifier.
-
#source_backup_vault ⇒ ::String
readonly
Output only.
-
#source_region ⇒ ::String
readonly
Output only.
-
#state ⇒ ::Google::Cloud::NetApp::V1::BackupVault::State
readonly
Output only.
Instance Attribute Details
#backup_region ⇒ ::String
Returns Optional. Region where the backups are stored.
Format: projects/{project_id}/locations/{location}.
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 |
# File 'proto_docs/google/cloud/netapp/v1/backup_vault.rb', line 80 class BackupVault include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Retention policy for backups in the backup vault # @!attribute [rw] backup_minimum_enforced_retention_days # @return [::Integer] # Required. Minimum retention duration in days for backups in the backup # vault. # @!attribute [rw] daily_backup_immutable # @return [::Boolean] # Optional. Indicates if the daily backups are immutable. # At least one of daily_backup_immutable, weekly_backup_immutable, # monthly_backup_immutable and manual_backup_immutable must be true. # @!attribute [rw] weekly_backup_immutable # @return [::Boolean] # Optional. Indicates if the weekly backups are immutable. # At least one of daily_backup_immutable, weekly_backup_immutable, # monthly_backup_immutable and manual_backup_immutable must be true. # @!attribute [rw] monthly_backup_immutable # @return [::Boolean] # Optional. Indicates if the monthly backups are immutable. # At least one of daily_backup_immutable, weekly_backup_immutable, # monthly_backup_immutable and manual_backup_immutable must be true. # @!attribute [rw] manual_backup_immutable # @return [::Boolean] # Optional. Indicates if the manual backups are immutable. # At least one of daily_backup_immutable, weekly_backup_immutable, # monthly_backup_immutable and manual_backup_immutable must be true. class BackupRetentionPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The Backup Vault States module State # State not set. STATE_UNSPECIFIED = 0 # BackupVault is being created. CREATING = 1 # BackupVault is available for use. READY = 2 # BackupVault is being deleted. DELETING = 3 # BackupVault is not valid and cannot be used. ERROR = 4 # BackupVault is being updated. UPDATING = 5 end # Backup Vault Type. module BackupVaultType # BackupVault type not set. BACKUP_VAULT_TYPE_UNSPECIFIED = 0 # BackupVault type is IN_REGION. IN_REGION = 1 # BackupVault type is CROSS_REGION. CROSS_REGION = 2 end # Encryption state of customer-managed encryption keys (CMEK) backups. module EncryptionState # Encryption state not set. ENCRYPTION_STATE_UNSPECIFIED = 0 # Encryption state is pending. ENCRYPTION_STATE_PENDING = 1 # Encryption is complete. ENCRYPTION_STATE_COMPLETED = 2 # Encryption is in progress. ENCRYPTION_STATE_IN_PROGRESS = 3 # Encryption has failed. ENCRYPTION_STATE_FAILED = 4 end end |
#backup_retention_policy ⇒ ::Google::Cloud::NetApp::V1::BackupVault::BackupRetentionPolicy
Returns Optional. Backup retention policy defining the retention of backups.
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 |
# File 'proto_docs/google/cloud/netapp/v1/backup_vault.rb', line 80 class BackupVault include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Retention policy for backups in the backup vault # @!attribute [rw] backup_minimum_enforced_retention_days # @return [::Integer] # Required. Minimum retention duration in days for backups in the backup # vault. # @!attribute [rw] daily_backup_immutable # @return [::Boolean] # Optional. Indicates if the daily backups are immutable. # At least one of daily_backup_immutable, weekly_backup_immutable, # monthly_backup_immutable and manual_backup_immutable must be true. # @!attribute [rw] weekly_backup_immutable # @return [::Boolean] # Optional. Indicates if the weekly backups are immutable. # At least one of daily_backup_immutable, weekly_backup_immutable, # monthly_backup_immutable and manual_backup_immutable must be true. # @!attribute [rw] monthly_backup_immutable # @return [::Boolean] # Optional. Indicates if the monthly backups are immutable. # At least one of daily_backup_immutable, weekly_backup_immutable, # monthly_backup_immutable and manual_backup_immutable must be true. # @!attribute [rw] manual_backup_immutable # @return [::Boolean] # Optional. Indicates if the manual backups are immutable. # At least one of daily_backup_immutable, weekly_backup_immutable, # monthly_backup_immutable and manual_backup_immutable must be true. class BackupRetentionPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The Backup Vault States module State # State not set. STATE_UNSPECIFIED = 0 # BackupVault is being created. CREATING = 1 # BackupVault is available for use. READY = 2 # BackupVault is being deleted. DELETING = 3 # BackupVault is not valid and cannot be used. ERROR = 4 # BackupVault is being updated. UPDATING = 5 end # Backup Vault Type. module BackupVaultType # BackupVault type not set. BACKUP_VAULT_TYPE_UNSPECIFIED = 0 # BackupVault type is IN_REGION. IN_REGION = 1 # BackupVault type is CROSS_REGION. CROSS_REGION = 2 end # Encryption state of customer-managed encryption keys (CMEK) backups. module EncryptionState # Encryption state not set. ENCRYPTION_STATE_UNSPECIFIED = 0 # Encryption state is pending. ENCRYPTION_STATE_PENDING = 1 # Encryption is complete. ENCRYPTION_STATE_COMPLETED = 2 # Encryption is in progress. ENCRYPTION_STATE_IN_PROGRESS = 3 # Encryption has failed. ENCRYPTION_STATE_FAILED = 4 end end |
#backup_vault_type ⇒ ::Google::Cloud::NetApp::V1::BackupVault::BackupVaultType
Returns Optional. Type of backup vault to be created. Default is IN_REGION.
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 |
# File 'proto_docs/google/cloud/netapp/v1/backup_vault.rb', line 80 class BackupVault include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Retention policy for backups in the backup vault # @!attribute [rw] backup_minimum_enforced_retention_days # @return [::Integer] # Required. Minimum retention duration in days for backups in the backup # vault. # @!attribute [rw] daily_backup_immutable # @return [::Boolean] # Optional. Indicates if the daily backups are immutable. # At least one of daily_backup_immutable, weekly_backup_immutable, # monthly_backup_immutable and manual_backup_immutable must be true. # @!attribute [rw] weekly_backup_immutable # @return [::Boolean] # Optional. Indicates if the weekly backups are immutable. # At least one of daily_backup_immutable, weekly_backup_immutable, # monthly_backup_immutable and manual_backup_immutable must be true. # @!attribute [rw] monthly_backup_immutable # @return [::Boolean] # Optional. Indicates if the monthly backups are immutable. # At least one of daily_backup_immutable, weekly_backup_immutable, # monthly_backup_immutable and manual_backup_immutable must be true. # @!attribute [rw] manual_backup_immutable # @return [::Boolean] # Optional. Indicates if the manual backups are immutable. # At least one of daily_backup_immutable, weekly_backup_immutable, # monthly_backup_immutable and manual_backup_immutable must be true. class BackupRetentionPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The Backup Vault States module State # State not set. STATE_UNSPECIFIED = 0 # BackupVault is being created. CREATING = 1 # BackupVault is available for use. READY = 2 # BackupVault is being deleted. DELETING = 3 # BackupVault is not valid and cannot be used. ERROR = 4 # BackupVault is being updated. UPDATING = 5 end # Backup Vault Type. module BackupVaultType # BackupVault type not set. BACKUP_VAULT_TYPE_UNSPECIFIED = 0 # BackupVault type is IN_REGION. IN_REGION = 1 # BackupVault type is CROSS_REGION. CROSS_REGION = 2 end # Encryption state of customer-managed encryption keys (CMEK) backups. module EncryptionState # Encryption state not set. ENCRYPTION_STATE_UNSPECIFIED = 0 # Encryption state is pending. ENCRYPTION_STATE_PENDING = 1 # Encryption is complete. ENCRYPTION_STATE_COMPLETED = 2 # Encryption is in progress. ENCRYPTION_STATE_IN_PROGRESS = 3 # Encryption has failed. ENCRYPTION_STATE_FAILED = 4 end end |
#backups_crypto_key_version ⇒ ::String (readonly)
Returns Output only. The crypto key version used to encrypt the backup vault.
Format:
projects/{project}/locations/{location}/keyRings/{key_ring}/cryptoKeys/{crypto_key}/cryptoKeyVersions/{crypto_key_version}.
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 |
# File 'proto_docs/google/cloud/netapp/v1/backup_vault.rb', line 80 class BackupVault include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Retention policy for backups in the backup vault # @!attribute [rw] backup_minimum_enforced_retention_days # @return [::Integer] # Required. Minimum retention duration in days for backups in the backup # vault. # @!attribute [rw] daily_backup_immutable # @return [::Boolean] # Optional. Indicates if the daily backups are immutable. # At least one of daily_backup_immutable, weekly_backup_immutable, # monthly_backup_immutable and manual_backup_immutable must be true. # @!attribute [rw] weekly_backup_immutable # @return [::Boolean] # Optional. Indicates if the weekly backups are immutable. # At least one of daily_backup_immutable, weekly_backup_immutable, # monthly_backup_immutable and manual_backup_immutable must be true. # @!attribute [rw] monthly_backup_immutable # @return [::Boolean] # Optional. Indicates if the monthly backups are immutable. # At least one of daily_backup_immutable, weekly_backup_immutable, # monthly_backup_immutable and manual_backup_immutable must be true. # @!attribute [rw] manual_backup_immutable # @return [::Boolean] # Optional. Indicates if the manual backups are immutable. # At least one of daily_backup_immutable, weekly_backup_immutable, # monthly_backup_immutable and manual_backup_immutable must be true. class BackupRetentionPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The Backup Vault States module State # State not set. STATE_UNSPECIFIED = 0 # BackupVault is being created. CREATING = 1 # BackupVault is available for use. READY = 2 # BackupVault is being deleted. DELETING = 3 # BackupVault is not valid and cannot be used. ERROR = 4 # BackupVault is being updated. UPDATING = 5 end # Backup Vault Type. module BackupVaultType # BackupVault type not set. BACKUP_VAULT_TYPE_UNSPECIFIED = 0 # BackupVault type is IN_REGION. IN_REGION = 1 # BackupVault type is CROSS_REGION. CROSS_REGION = 2 end # Encryption state of customer-managed encryption keys (CMEK) backups. module EncryptionState # Encryption state not set. ENCRYPTION_STATE_UNSPECIFIED = 0 # Encryption state is pending. ENCRYPTION_STATE_PENDING = 1 # Encryption is complete. ENCRYPTION_STATE_COMPLETED = 2 # Encryption is in progress. ENCRYPTION_STATE_IN_PROGRESS = 3 # Encryption has failed. ENCRYPTION_STATE_FAILED = 4 end end |
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Create time of the backup vault.
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 |
# File 'proto_docs/google/cloud/netapp/v1/backup_vault.rb', line 80 class BackupVault include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Retention policy for backups in the backup vault # @!attribute [rw] backup_minimum_enforced_retention_days # @return [::Integer] # Required. Minimum retention duration in days for backups in the backup # vault. # @!attribute [rw] daily_backup_immutable # @return [::Boolean] # Optional. Indicates if the daily backups are immutable. # At least one of daily_backup_immutable, weekly_backup_immutable, # monthly_backup_immutable and manual_backup_immutable must be true. # @!attribute [rw] weekly_backup_immutable # @return [::Boolean] # Optional. Indicates if the weekly backups are immutable. # At least one of daily_backup_immutable, weekly_backup_immutable, # monthly_backup_immutable and manual_backup_immutable must be true. # @!attribute [rw] monthly_backup_immutable # @return [::Boolean] # Optional. Indicates if the monthly backups are immutable. # At least one of daily_backup_immutable, weekly_backup_immutable, # monthly_backup_immutable and manual_backup_immutable must be true. # @!attribute [rw] manual_backup_immutable # @return [::Boolean] # Optional. Indicates if the manual backups are immutable. # At least one of daily_backup_immutable, weekly_backup_immutable, # monthly_backup_immutable and manual_backup_immutable must be true. class BackupRetentionPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The Backup Vault States module State # State not set. STATE_UNSPECIFIED = 0 # BackupVault is being created. CREATING = 1 # BackupVault is available for use. READY = 2 # BackupVault is being deleted. DELETING = 3 # BackupVault is not valid and cannot be used. ERROR = 4 # BackupVault is being updated. UPDATING = 5 end # Backup Vault Type. module BackupVaultType # BackupVault type not set. BACKUP_VAULT_TYPE_UNSPECIFIED = 0 # BackupVault type is IN_REGION. IN_REGION = 1 # BackupVault type is CROSS_REGION. CROSS_REGION = 2 end # Encryption state of customer-managed encryption keys (CMEK) backups. module EncryptionState # Encryption state not set. ENCRYPTION_STATE_UNSPECIFIED = 0 # Encryption state is pending. ENCRYPTION_STATE_PENDING = 1 # Encryption is complete. ENCRYPTION_STATE_COMPLETED = 2 # Encryption is in progress. ENCRYPTION_STATE_IN_PROGRESS = 3 # Encryption has failed. ENCRYPTION_STATE_FAILED = 4 end end |
#description ⇒ ::String
Returns Description of the backup vault.
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 |
# File 'proto_docs/google/cloud/netapp/v1/backup_vault.rb', line 80 class BackupVault include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Retention policy for backups in the backup vault # @!attribute [rw] backup_minimum_enforced_retention_days # @return [::Integer] # Required. Minimum retention duration in days for backups in the backup # vault. # @!attribute [rw] daily_backup_immutable # @return [::Boolean] # Optional. Indicates if the daily backups are immutable. # At least one of daily_backup_immutable, weekly_backup_immutable, # monthly_backup_immutable and manual_backup_immutable must be true. # @!attribute [rw] weekly_backup_immutable # @return [::Boolean] # Optional. Indicates if the weekly backups are immutable. # At least one of daily_backup_immutable, weekly_backup_immutable, # monthly_backup_immutable and manual_backup_immutable must be true. # @!attribute [rw] monthly_backup_immutable # @return [::Boolean] # Optional. Indicates if the monthly backups are immutable. # At least one of daily_backup_immutable, weekly_backup_immutable, # monthly_backup_immutable and manual_backup_immutable must be true. # @!attribute [rw] manual_backup_immutable # @return [::Boolean] # Optional. Indicates if the manual backups are immutable. # At least one of daily_backup_immutable, weekly_backup_immutable, # monthly_backup_immutable and manual_backup_immutable must be true. class BackupRetentionPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The Backup Vault States module State # State not set. STATE_UNSPECIFIED = 0 # BackupVault is being created. CREATING = 1 # BackupVault is available for use. READY = 2 # BackupVault is being deleted. DELETING = 3 # BackupVault is not valid and cannot be used. ERROR = 4 # BackupVault is being updated. UPDATING = 5 end # Backup Vault Type. module BackupVaultType # BackupVault type not set. BACKUP_VAULT_TYPE_UNSPECIFIED = 0 # BackupVault type is IN_REGION. IN_REGION = 1 # BackupVault type is CROSS_REGION. CROSS_REGION = 2 end # Encryption state of customer-managed encryption keys (CMEK) backups. module EncryptionState # Encryption state not set. ENCRYPTION_STATE_UNSPECIFIED = 0 # Encryption state is pending. ENCRYPTION_STATE_PENDING = 1 # Encryption is complete. ENCRYPTION_STATE_COMPLETED = 2 # Encryption is in progress. ENCRYPTION_STATE_IN_PROGRESS = 3 # Encryption has failed. ENCRYPTION_STATE_FAILED = 4 end end |
#destination_backup_vault ⇒ ::String (readonly)
Returns Output only. Name of the Backup vault created in backup region.
Format:
projects/{project_id}/locations/{location}/backupVaults/{backup_vault_id}.
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 |
# File 'proto_docs/google/cloud/netapp/v1/backup_vault.rb', line 80 class BackupVault include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Retention policy for backups in the backup vault # @!attribute [rw] backup_minimum_enforced_retention_days # @return [::Integer] # Required. Minimum retention duration in days for backups in the backup # vault. # @!attribute [rw] daily_backup_immutable # @return [::Boolean] # Optional. Indicates if the daily backups are immutable. # At least one of daily_backup_immutable, weekly_backup_immutable, # monthly_backup_immutable and manual_backup_immutable must be true. # @!attribute [rw] weekly_backup_immutable # @return [::Boolean] # Optional. Indicates if the weekly backups are immutable. # At least one of daily_backup_immutable, weekly_backup_immutable, # monthly_backup_immutable and manual_backup_immutable must be true. # @!attribute [rw] monthly_backup_immutable # @return [::Boolean] # Optional. Indicates if the monthly backups are immutable. # At least one of daily_backup_immutable, weekly_backup_immutable, # monthly_backup_immutable and manual_backup_immutable must be true. # @!attribute [rw] manual_backup_immutable # @return [::Boolean] # Optional. Indicates if the manual backups are immutable. # At least one of daily_backup_immutable, weekly_backup_immutable, # monthly_backup_immutable and manual_backup_immutable must be true. class BackupRetentionPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The Backup Vault States module State # State not set. STATE_UNSPECIFIED = 0 # BackupVault is being created. CREATING = 1 # BackupVault is available for use. READY = 2 # BackupVault is being deleted. DELETING = 3 # BackupVault is not valid and cannot be used. ERROR = 4 # BackupVault is being updated. UPDATING = 5 end # Backup Vault Type. module BackupVaultType # BackupVault type not set. BACKUP_VAULT_TYPE_UNSPECIFIED = 0 # BackupVault type is IN_REGION. IN_REGION = 1 # BackupVault type is CROSS_REGION. CROSS_REGION = 2 end # Encryption state of customer-managed encryption keys (CMEK) backups. module EncryptionState # Encryption state not set. ENCRYPTION_STATE_UNSPECIFIED = 0 # Encryption state is pending. ENCRYPTION_STATE_PENDING = 1 # Encryption is complete. ENCRYPTION_STATE_COMPLETED = 2 # Encryption is in progress. ENCRYPTION_STATE_IN_PROGRESS = 3 # Encryption has failed. ENCRYPTION_STATE_FAILED = 4 end end |
#encryption_state ⇒ ::Google::Cloud::NetApp::V1::BackupVault::EncryptionState (readonly)
Returns Output only. Field indicating encryption state of CMEK backups.
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 |
# File 'proto_docs/google/cloud/netapp/v1/backup_vault.rb', line 80 class BackupVault include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Retention policy for backups in the backup vault # @!attribute [rw] backup_minimum_enforced_retention_days # @return [::Integer] # Required. Minimum retention duration in days for backups in the backup # vault. # @!attribute [rw] daily_backup_immutable # @return [::Boolean] # Optional. Indicates if the daily backups are immutable. # At least one of daily_backup_immutable, weekly_backup_immutable, # monthly_backup_immutable and manual_backup_immutable must be true. # @!attribute [rw] weekly_backup_immutable # @return [::Boolean] # Optional. Indicates if the weekly backups are immutable. # At least one of daily_backup_immutable, weekly_backup_immutable, # monthly_backup_immutable and manual_backup_immutable must be true. # @!attribute [rw] monthly_backup_immutable # @return [::Boolean] # Optional. Indicates if the monthly backups are immutable. # At least one of daily_backup_immutable, weekly_backup_immutable, # monthly_backup_immutable and manual_backup_immutable must be true. # @!attribute [rw] manual_backup_immutable # @return [::Boolean] # Optional. Indicates if the manual backups are immutable. # At least one of daily_backup_immutable, weekly_backup_immutable, # monthly_backup_immutable and manual_backup_immutable must be true. class BackupRetentionPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The Backup Vault States module State # State not set. STATE_UNSPECIFIED = 0 # BackupVault is being created. CREATING = 1 # BackupVault is available for use. READY = 2 # BackupVault is being deleted. DELETING = 3 # BackupVault is not valid and cannot be used. ERROR = 4 # BackupVault is being updated. UPDATING = 5 end # Backup Vault Type. module BackupVaultType # BackupVault type not set. BACKUP_VAULT_TYPE_UNSPECIFIED = 0 # BackupVault type is IN_REGION. IN_REGION = 1 # BackupVault type is CROSS_REGION. CROSS_REGION = 2 end # Encryption state of customer-managed encryption keys (CMEK) backups. module EncryptionState # Encryption state not set. ENCRYPTION_STATE_UNSPECIFIED = 0 # Encryption state is pending. ENCRYPTION_STATE_PENDING = 1 # Encryption is complete. ENCRYPTION_STATE_COMPLETED = 2 # Encryption is in progress. ENCRYPTION_STATE_IN_PROGRESS = 3 # Encryption has failed. ENCRYPTION_STATE_FAILED = 4 end end |
#kms_config ⇒ ::String
Returns Optional. Specifies the Key Management System (KMS) configuration to be
used for backup encryption. Format:
projects/{project}/locations/{location}/kmsConfigs/{kms_config}.
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 |
# File 'proto_docs/google/cloud/netapp/v1/backup_vault.rb', line 80 class BackupVault include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Retention policy for backups in the backup vault # @!attribute [rw] backup_minimum_enforced_retention_days # @return [::Integer] # Required. Minimum retention duration in days for backups in the backup # vault. # @!attribute [rw] daily_backup_immutable # @return [::Boolean] # Optional. Indicates if the daily backups are immutable. # At least one of daily_backup_immutable, weekly_backup_immutable, # monthly_backup_immutable and manual_backup_immutable must be true. # @!attribute [rw] weekly_backup_immutable # @return [::Boolean] # Optional. Indicates if the weekly backups are immutable. # At least one of daily_backup_immutable, weekly_backup_immutable, # monthly_backup_immutable and manual_backup_immutable must be true. # @!attribute [rw] monthly_backup_immutable # @return [::Boolean] # Optional. Indicates if the monthly backups are immutable. # At least one of daily_backup_immutable, weekly_backup_immutable, # monthly_backup_immutable and manual_backup_immutable must be true. # @!attribute [rw] manual_backup_immutable # @return [::Boolean] # Optional. Indicates if the manual backups are immutable. # At least one of daily_backup_immutable, weekly_backup_immutable, # monthly_backup_immutable and manual_backup_immutable must be true. class BackupRetentionPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The Backup Vault States module State # State not set. STATE_UNSPECIFIED = 0 # BackupVault is being created. CREATING = 1 # BackupVault is available for use. READY = 2 # BackupVault is being deleted. DELETING = 3 # BackupVault is not valid and cannot be used. ERROR = 4 # BackupVault is being updated. UPDATING = 5 end # Backup Vault Type. module BackupVaultType # BackupVault type not set. BACKUP_VAULT_TYPE_UNSPECIFIED = 0 # BackupVault type is IN_REGION. IN_REGION = 1 # BackupVault type is CROSS_REGION. CROSS_REGION = 2 end # Encryption state of customer-managed encryption keys (CMEK) backups. module EncryptionState # Encryption state not set. ENCRYPTION_STATE_UNSPECIFIED = 0 # Encryption state is pending. ENCRYPTION_STATE_PENDING = 1 # Encryption is complete. ENCRYPTION_STATE_COMPLETED = 2 # Encryption is in progress. ENCRYPTION_STATE_IN_PROGRESS = 3 # Encryption has failed. ENCRYPTION_STATE_FAILED = 4 end end |
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Resource labels to represent user provided metadata.
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 |
# File 'proto_docs/google/cloud/netapp/v1/backup_vault.rb', line 80 class BackupVault include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Retention policy for backups in the backup vault # @!attribute [rw] backup_minimum_enforced_retention_days # @return [::Integer] # Required. Minimum retention duration in days for backups in the backup # vault. # @!attribute [rw] daily_backup_immutable # @return [::Boolean] # Optional. Indicates if the daily backups are immutable. # At least one of daily_backup_immutable, weekly_backup_immutable, # monthly_backup_immutable and manual_backup_immutable must be true. # @!attribute [rw] weekly_backup_immutable # @return [::Boolean] # Optional. Indicates if the weekly backups are immutable. # At least one of daily_backup_immutable, weekly_backup_immutable, # monthly_backup_immutable and manual_backup_immutable must be true. # @!attribute [rw] monthly_backup_immutable # @return [::Boolean] # Optional. Indicates if the monthly backups are immutable. # At least one of daily_backup_immutable, weekly_backup_immutable, # monthly_backup_immutable and manual_backup_immutable must be true. # @!attribute [rw] manual_backup_immutable # @return [::Boolean] # Optional. Indicates if the manual backups are immutable. # At least one of daily_backup_immutable, weekly_backup_immutable, # monthly_backup_immutable and manual_backup_immutable must be true. class BackupRetentionPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The Backup Vault States module State # State not set. STATE_UNSPECIFIED = 0 # BackupVault is being created. CREATING = 1 # BackupVault is available for use. READY = 2 # BackupVault is being deleted. DELETING = 3 # BackupVault is not valid and cannot be used. ERROR = 4 # BackupVault is being updated. UPDATING = 5 end # Backup Vault Type. module BackupVaultType # BackupVault type not set. BACKUP_VAULT_TYPE_UNSPECIFIED = 0 # BackupVault type is IN_REGION. IN_REGION = 1 # BackupVault type is CROSS_REGION. CROSS_REGION = 2 end # Encryption state of customer-managed encryption keys (CMEK) backups. module EncryptionState # Encryption state not set. ENCRYPTION_STATE_UNSPECIFIED = 0 # Encryption state is pending. ENCRYPTION_STATE_PENDING = 1 # Encryption is complete. ENCRYPTION_STATE_COMPLETED = 2 # Encryption is in progress. ENCRYPTION_STATE_IN_PROGRESS = 3 # Encryption has failed. ENCRYPTION_STATE_FAILED = 4 end end |
#name ⇒ ::String
Returns Identifier. The resource name of the backup vault.
Format:
projects/{project_id}/locations/{location}/backupVaults/{backup_vault_id}.
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 |
# File 'proto_docs/google/cloud/netapp/v1/backup_vault.rb', line 80 class BackupVault include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Retention policy for backups in the backup vault # @!attribute [rw] backup_minimum_enforced_retention_days # @return [::Integer] # Required. Minimum retention duration in days for backups in the backup # vault. # @!attribute [rw] daily_backup_immutable # @return [::Boolean] # Optional. Indicates if the daily backups are immutable. # At least one of daily_backup_immutable, weekly_backup_immutable, # monthly_backup_immutable and manual_backup_immutable must be true. # @!attribute [rw] weekly_backup_immutable # @return [::Boolean] # Optional. Indicates if the weekly backups are immutable. # At least one of daily_backup_immutable, weekly_backup_immutable, # monthly_backup_immutable and manual_backup_immutable must be true. # @!attribute [rw] monthly_backup_immutable # @return [::Boolean] # Optional. Indicates if the monthly backups are immutable. # At least one of daily_backup_immutable, weekly_backup_immutable, # monthly_backup_immutable and manual_backup_immutable must be true. # @!attribute [rw] manual_backup_immutable # @return [::Boolean] # Optional. Indicates if the manual backups are immutable. # At least one of daily_backup_immutable, weekly_backup_immutable, # monthly_backup_immutable and manual_backup_immutable must be true. class BackupRetentionPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The Backup Vault States module State # State not set. STATE_UNSPECIFIED = 0 # BackupVault is being created. CREATING = 1 # BackupVault is available for use. READY = 2 # BackupVault is being deleted. DELETING = 3 # BackupVault is not valid and cannot be used. ERROR = 4 # BackupVault is being updated. UPDATING = 5 end # Backup Vault Type. module BackupVaultType # BackupVault type not set. BACKUP_VAULT_TYPE_UNSPECIFIED = 0 # BackupVault type is IN_REGION. IN_REGION = 1 # BackupVault type is CROSS_REGION. CROSS_REGION = 2 end # Encryption state of customer-managed encryption keys (CMEK) backups. module EncryptionState # Encryption state not set. ENCRYPTION_STATE_UNSPECIFIED = 0 # Encryption state is pending. ENCRYPTION_STATE_PENDING = 1 # Encryption is complete. ENCRYPTION_STATE_COMPLETED = 2 # Encryption is in progress. ENCRYPTION_STATE_IN_PROGRESS = 3 # Encryption has failed. ENCRYPTION_STATE_FAILED = 4 end end |
#source_backup_vault ⇒ ::String (readonly)
Returns Output only. Name of the Backup vault created in source region.
Format:
projects/{project_id}/locations/{location}/backupVaults/{backup_vault_id}.
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 |
# File 'proto_docs/google/cloud/netapp/v1/backup_vault.rb', line 80 class BackupVault include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Retention policy for backups in the backup vault # @!attribute [rw] backup_minimum_enforced_retention_days # @return [::Integer] # Required. Minimum retention duration in days for backups in the backup # vault. # @!attribute [rw] daily_backup_immutable # @return [::Boolean] # Optional. Indicates if the daily backups are immutable. # At least one of daily_backup_immutable, weekly_backup_immutable, # monthly_backup_immutable and manual_backup_immutable must be true. # @!attribute [rw] weekly_backup_immutable # @return [::Boolean] # Optional. Indicates if the weekly backups are immutable. # At least one of daily_backup_immutable, weekly_backup_immutable, # monthly_backup_immutable and manual_backup_immutable must be true. # @!attribute [rw] monthly_backup_immutable # @return [::Boolean] # Optional. Indicates if the monthly backups are immutable. # At least one of daily_backup_immutable, weekly_backup_immutable, # monthly_backup_immutable and manual_backup_immutable must be true. # @!attribute [rw] manual_backup_immutable # @return [::Boolean] # Optional. Indicates if the manual backups are immutable. # At least one of daily_backup_immutable, weekly_backup_immutable, # monthly_backup_immutable and manual_backup_immutable must be true. class BackupRetentionPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The Backup Vault States module State # State not set. STATE_UNSPECIFIED = 0 # BackupVault is being created. CREATING = 1 # BackupVault is available for use. READY = 2 # BackupVault is being deleted. DELETING = 3 # BackupVault is not valid and cannot be used. ERROR = 4 # BackupVault is being updated. UPDATING = 5 end # Backup Vault Type. module BackupVaultType # BackupVault type not set. BACKUP_VAULT_TYPE_UNSPECIFIED = 0 # BackupVault type is IN_REGION. IN_REGION = 1 # BackupVault type is CROSS_REGION. CROSS_REGION = 2 end # Encryption state of customer-managed encryption keys (CMEK) backups. module EncryptionState # Encryption state not set. ENCRYPTION_STATE_UNSPECIFIED = 0 # Encryption state is pending. ENCRYPTION_STATE_PENDING = 1 # Encryption is complete. ENCRYPTION_STATE_COMPLETED = 2 # Encryption is in progress. ENCRYPTION_STATE_IN_PROGRESS = 3 # Encryption has failed. ENCRYPTION_STATE_FAILED = 4 end end |
#source_region ⇒ ::String (readonly)
Returns Output only. Region in which the backup vault is created.
Format: projects/{project_id}/locations/{location}.
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 |
# File 'proto_docs/google/cloud/netapp/v1/backup_vault.rb', line 80 class BackupVault include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Retention policy for backups in the backup vault # @!attribute [rw] backup_minimum_enforced_retention_days # @return [::Integer] # Required. Minimum retention duration in days for backups in the backup # vault. # @!attribute [rw] daily_backup_immutable # @return [::Boolean] # Optional. Indicates if the daily backups are immutable. # At least one of daily_backup_immutable, weekly_backup_immutable, # monthly_backup_immutable and manual_backup_immutable must be true. # @!attribute [rw] weekly_backup_immutable # @return [::Boolean] # Optional. Indicates if the weekly backups are immutable. # At least one of daily_backup_immutable, weekly_backup_immutable, # monthly_backup_immutable and manual_backup_immutable must be true. # @!attribute [rw] monthly_backup_immutable # @return [::Boolean] # Optional. Indicates if the monthly backups are immutable. # At least one of daily_backup_immutable, weekly_backup_immutable, # monthly_backup_immutable and manual_backup_immutable must be true. # @!attribute [rw] manual_backup_immutable # @return [::Boolean] # Optional. Indicates if the manual backups are immutable. # At least one of daily_backup_immutable, weekly_backup_immutable, # monthly_backup_immutable and manual_backup_immutable must be true. class BackupRetentionPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The Backup Vault States module State # State not set. STATE_UNSPECIFIED = 0 # BackupVault is being created. CREATING = 1 # BackupVault is available for use. READY = 2 # BackupVault is being deleted. DELETING = 3 # BackupVault is not valid and cannot be used. ERROR = 4 # BackupVault is being updated. UPDATING = 5 end # Backup Vault Type. module BackupVaultType # BackupVault type not set. BACKUP_VAULT_TYPE_UNSPECIFIED = 0 # BackupVault type is IN_REGION. IN_REGION = 1 # BackupVault type is CROSS_REGION. CROSS_REGION = 2 end # Encryption state of customer-managed encryption keys (CMEK) backups. module EncryptionState # Encryption state not set. ENCRYPTION_STATE_UNSPECIFIED = 0 # Encryption state is pending. ENCRYPTION_STATE_PENDING = 1 # Encryption is complete. ENCRYPTION_STATE_COMPLETED = 2 # Encryption is in progress. ENCRYPTION_STATE_IN_PROGRESS = 3 # Encryption has failed. ENCRYPTION_STATE_FAILED = 4 end end |
#state ⇒ ::Google::Cloud::NetApp::V1::BackupVault::State (readonly)
Returns Output only. The backup vault state.
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 |
# File 'proto_docs/google/cloud/netapp/v1/backup_vault.rb', line 80 class BackupVault include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Retention policy for backups in the backup vault # @!attribute [rw] backup_minimum_enforced_retention_days # @return [::Integer] # Required. Minimum retention duration in days for backups in the backup # vault. # @!attribute [rw] daily_backup_immutable # @return [::Boolean] # Optional. Indicates if the daily backups are immutable. # At least one of daily_backup_immutable, weekly_backup_immutable, # monthly_backup_immutable and manual_backup_immutable must be true. # @!attribute [rw] weekly_backup_immutable # @return [::Boolean] # Optional. Indicates if the weekly backups are immutable. # At least one of daily_backup_immutable, weekly_backup_immutable, # monthly_backup_immutable and manual_backup_immutable must be true. # @!attribute [rw] monthly_backup_immutable # @return [::Boolean] # Optional. Indicates if the monthly backups are immutable. # At least one of daily_backup_immutable, weekly_backup_immutable, # monthly_backup_immutable and manual_backup_immutable must be true. # @!attribute [rw] manual_backup_immutable # @return [::Boolean] # Optional. Indicates if the manual backups are immutable. # At least one of daily_backup_immutable, weekly_backup_immutable, # monthly_backup_immutable and manual_backup_immutable must be true. class BackupRetentionPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The Backup Vault States module State # State not set. STATE_UNSPECIFIED = 0 # BackupVault is being created. CREATING = 1 # BackupVault is available for use. READY = 2 # BackupVault is being deleted. DELETING = 3 # BackupVault is not valid and cannot be used. ERROR = 4 # BackupVault is being updated. UPDATING = 5 end # Backup Vault Type. module BackupVaultType # BackupVault type not set. BACKUP_VAULT_TYPE_UNSPECIFIED = 0 # BackupVault type is IN_REGION. IN_REGION = 1 # BackupVault type is CROSS_REGION. CROSS_REGION = 2 end # Encryption state of customer-managed encryption keys (CMEK) backups. module EncryptionState # Encryption state not set. ENCRYPTION_STATE_UNSPECIFIED = 0 # Encryption state is pending. ENCRYPTION_STATE_PENDING = 1 # Encryption is complete. ENCRYPTION_STATE_COMPLETED = 2 # Encryption is in progress. ENCRYPTION_STATE_IN_PROGRESS = 3 # Encryption has failed. ENCRYPTION_STATE_FAILED = 4 end end |