Class: Google::Cloud::NetApp::V1::BlockDevice
- Inherits:
-
Object
- Object
- Google::Cloud::NetApp::V1::BlockDevice
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/netapp/v1/volume.rb
Overview
Block device represents the device(s) which are stored in the block volume.
Instance Attribute Summary collapse
-
#host_groups ⇒ ::Array<::String>
Optional.
-
#identifier ⇒ ::String
readonly
Output only.
-
#name ⇒ ::String
Optional.
-
#os_type ⇒ ::Google::Cloud::NetApp::V1::OsType
Required.
-
#size_gib ⇒ ::Integer
Optional.
Instance Attribute Details
#host_groups ⇒ ::Array<::String>
Returns Optional. A list of host groups that identify hosts that can mount the
block volume. Format:
projects/{project_id}/locations/{location}/hostGroups/{host_group_id}
This field can be updated after the block device is created.
875 876 877 878 |
# File 'proto_docs/google/cloud/netapp/v1/volume.rb', line 875 class BlockDevice include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#identifier ⇒ ::String (readonly)
Returns Output only. Device identifier of the block volume. This represents
lun_serial_number for iSCSI volumes.
875 876 877 878 |
# File 'proto_docs/google/cloud/netapp/v1/volume.rb', line 875 class BlockDevice include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Optional. User-defined name for the block device, unique within the volume. In case no user input is provided, name will be auto-generated in the backend. The name must meet the following requirements:
- Be between 1 and 255 characters long.
- Contain only uppercase or lowercase letters (A-Z, a-z), numbers (0-9), and the following special characters: "-", "_", "}", "{", ".".
- Spaces are not allowed.
875 876 877 878 |
# File 'proto_docs/google/cloud/netapp/v1/volume.rb', line 875 class BlockDevice include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#os_type ⇒ ::Google::Cloud::NetApp::V1::OsType
Returns Required. Immutable. The OS type of the volume. This field can't be changed after the block device is created.
875 876 877 878 |
# File 'proto_docs/google/cloud/netapp/v1/volume.rb', line 875 class BlockDevice include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#size_gib ⇒ ::Integer
Returns Optional. The size of the block device in GiB.
Any value provided for the size_gib field during volume creation is
ignored. The block device's size is system-managed and will be set to match
the parent Volume's capacity_gib.
875 876 877 878 |
# File 'proto_docs/google/cloud/netapp/v1/volume.rb', line 875 class BlockDevice include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |