Class: Google::Cloud::NetApp::V1::CreateHostGroupRequest
- Inherits:
-
Object
- Object
- Google::Cloud::NetApp::V1::CreateHostGroupRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/netapp/v1/host_group.rb
Overview
CreateHostGroupRequest for creating a host group.
Instance Attribute Summary collapse
-
#host_group ⇒ ::Google::Cloud::NetApp::V1::HostGroup
Required.
-
#host_group_id ⇒ ::String
Required.
-
#parent ⇒ ::String
Required.
Instance Attribute Details
#host_group ⇒ ::Google::Cloud::NetApp::V1::HostGroup
Returns Required. Fields of the host group to create.
85 86 87 88 |
# File 'proto_docs/google/cloud/netapp/v1/host_group.rb', line 85 class CreateHostGroupRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#host_group_id ⇒ ::String
Returns Required. ID of the host group to create. Must be unique within the parent resource. Must contain only letters, numbers, and hyphen, with the first character a letter or underscore, the last a letter or underscore or a number, and a 63 character maximum.
85 86 87 88 |
# File 'proto_docs/google/cloud/netapp/v1/host_group.rb', line 85 class CreateHostGroupRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. Parent value for CreateHostGroupRequest.
85 86 87 88 |
# File 'proto_docs/google/cloud/netapp/v1/host_group.rb', line 85 class CreateHostGroupRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |