Class: Google::Cloud::NetApp::V1::HybridReplicationParameters
- Inherits:
-
Object
- Object
- Google::Cloud::NetApp::V1::HybridReplicationParameters
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/netapp/v1/volume.rb
Overview
The Hybrid Replication parameters for the volume.
Defined Under Namespace
Modules: VolumeHybridReplicationType Classes: LabelsEntry
Instance Attribute Summary collapse
-
#cluster_location ⇒ ::String
Optional.
-
#description ⇒ ::String
Optional.
-
#hybrid_replication_type ⇒ ::Google::Cloud::NetApp::V1::HybridReplicationParameters::VolumeHybridReplicationType
Optional.
-
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Optional.
-
#large_volume_constituent_count ⇒ ::Integer
Optional.
-
#peer_cluster_name ⇒ ::String
Required.
-
#peer_ip_addresses ⇒ ::Array<::String>
Required.
-
#peer_svm_name ⇒ ::String
Required.
-
#peer_volume_name ⇒ ::String
Required.
-
#replication ⇒ ::String
Required.
-
#replication_schedule ⇒ ::Google::Cloud::NetApp::V1::HybridReplicationSchedule
Optional.
Instance Attribute Details
#cluster_location ⇒ ::String
Returns Optional. Name of source cluster location associated with the Hybrid replication. This is a free-form field for the display purpose only.
687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 |
# File 'proto_docs/google/cloud/netapp/v1/volume.rb', line 687 class HybridReplicationParameters include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Type of the volume's hybrid replication. module VolumeHybridReplicationType # Unspecified hybrid replication type. VOLUME_HYBRID_REPLICATION_TYPE_UNSPECIFIED = 0 # Hybrid replication type for migration. MIGRATION = 1 # Hybrid replication type for continuous replication. CONTINUOUS_REPLICATION = 2 # New field for reversible OnPrem replication, to be used for data # protection. ONPREM_REPLICATION = 3 # New field for reversible OnPrem replication, to be used for data # protection. REVERSE_ONPREM_REPLICATION = 4 end end |
#description ⇒ ::String
Returns Optional. Description of the replication.
687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 |
# File 'proto_docs/google/cloud/netapp/v1/volume.rb', line 687 class HybridReplicationParameters include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Type of the volume's hybrid replication. module VolumeHybridReplicationType # Unspecified hybrid replication type. VOLUME_HYBRID_REPLICATION_TYPE_UNSPECIFIED = 0 # Hybrid replication type for migration. MIGRATION = 1 # Hybrid replication type for continuous replication. CONTINUOUS_REPLICATION = 2 # New field for reversible OnPrem replication, to be used for data # protection. ONPREM_REPLICATION = 3 # New field for reversible OnPrem replication, to be used for data # protection. REVERSE_ONPREM_REPLICATION = 4 end end |
#hybrid_replication_type ⇒ ::Google::Cloud::NetApp::V1::HybridReplicationParameters::VolumeHybridReplicationType
Returns Optional. Type of the hybrid replication.
687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 |
# File 'proto_docs/google/cloud/netapp/v1/volume.rb', line 687 class HybridReplicationParameters include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Type of the volume's hybrid replication. module VolumeHybridReplicationType # Unspecified hybrid replication type. VOLUME_HYBRID_REPLICATION_TYPE_UNSPECIFIED = 0 # Hybrid replication type for migration. MIGRATION = 1 # Hybrid replication type for continuous replication. CONTINUOUS_REPLICATION = 2 # New field for reversible OnPrem replication, to be used for data # protection. ONPREM_REPLICATION = 3 # New field for reversible OnPrem replication, to be used for data # protection. REVERSE_ONPREM_REPLICATION = 4 end end |
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Optional. Labels to be added to the replication as the key value pairs.
687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 |
# File 'proto_docs/google/cloud/netapp/v1/volume.rb', line 687 class HybridReplicationParameters include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Type of the volume's hybrid replication. module VolumeHybridReplicationType # Unspecified hybrid replication type. VOLUME_HYBRID_REPLICATION_TYPE_UNSPECIFIED = 0 # Hybrid replication type for migration. MIGRATION = 1 # Hybrid replication type for continuous replication. CONTINUOUS_REPLICATION = 2 # New field for reversible OnPrem replication, to be used for data # protection. ONPREM_REPLICATION = 3 # New field for reversible OnPrem replication, to be used for data # protection. REVERSE_ONPREM_REPLICATION = 4 end end |
#large_volume_constituent_count ⇒ ::Integer
Returns Optional. Constituent volume count for large volume.
687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 |
# File 'proto_docs/google/cloud/netapp/v1/volume.rb', line 687 class HybridReplicationParameters include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Type of the volume's hybrid replication. module VolumeHybridReplicationType # Unspecified hybrid replication type. VOLUME_HYBRID_REPLICATION_TYPE_UNSPECIFIED = 0 # Hybrid replication type for migration. MIGRATION = 1 # Hybrid replication type for continuous replication. CONTINUOUS_REPLICATION = 2 # New field for reversible OnPrem replication, to be used for data # protection. ONPREM_REPLICATION = 3 # New field for reversible OnPrem replication, to be used for data # protection. REVERSE_ONPREM_REPLICATION = 4 end end |
#peer_cluster_name ⇒ ::String
Returns Required. Name of the user's local source cluster to be peered with the destination cluster.
687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 |
# File 'proto_docs/google/cloud/netapp/v1/volume.rb', line 687 class HybridReplicationParameters include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Type of the volume's hybrid replication. module VolumeHybridReplicationType # Unspecified hybrid replication type. VOLUME_HYBRID_REPLICATION_TYPE_UNSPECIFIED = 0 # Hybrid replication type for migration. MIGRATION = 1 # Hybrid replication type for continuous replication. CONTINUOUS_REPLICATION = 2 # New field for reversible OnPrem replication, to be used for data # protection. ONPREM_REPLICATION = 3 # New field for reversible OnPrem replication, to be used for data # protection. REVERSE_ONPREM_REPLICATION = 4 end end |
#peer_ip_addresses ⇒ ::Array<::String>
Returns Required. List of node ip addresses to be peered with.
687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 |
# File 'proto_docs/google/cloud/netapp/v1/volume.rb', line 687 class HybridReplicationParameters include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Type of the volume's hybrid replication. module VolumeHybridReplicationType # Unspecified hybrid replication type. VOLUME_HYBRID_REPLICATION_TYPE_UNSPECIFIED = 0 # Hybrid replication type for migration. MIGRATION = 1 # Hybrid replication type for continuous replication. CONTINUOUS_REPLICATION = 2 # New field for reversible OnPrem replication, to be used for data # protection. ONPREM_REPLICATION = 3 # New field for reversible OnPrem replication, to be used for data # protection. REVERSE_ONPREM_REPLICATION = 4 end end |
#peer_svm_name ⇒ ::String
Returns Required. Name of the user's local source vserver svm to be peered with the destination vserver svm.
687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 |
# File 'proto_docs/google/cloud/netapp/v1/volume.rb', line 687 class HybridReplicationParameters include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Type of the volume's hybrid replication. module VolumeHybridReplicationType # Unspecified hybrid replication type. VOLUME_HYBRID_REPLICATION_TYPE_UNSPECIFIED = 0 # Hybrid replication type for migration. MIGRATION = 1 # Hybrid replication type for continuous replication. CONTINUOUS_REPLICATION = 2 # New field for reversible OnPrem replication, to be used for data # protection. ONPREM_REPLICATION = 3 # New field for reversible OnPrem replication, to be used for data # protection. REVERSE_ONPREM_REPLICATION = 4 end end |
#peer_volume_name ⇒ ::String
Returns Required. Name of the user's local source volume to be peered with the destination volume.
687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 |
# File 'proto_docs/google/cloud/netapp/v1/volume.rb', line 687 class HybridReplicationParameters include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Type of the volume's hybrid replication. module VolumeHybridReplicationType # Unspecified hybrid replication type. VOLUME_HYBRID_REPLICATION_TYPE_UNSPECIFIED = 0 # Hybrid replication type for migration. MIGRATION = 1 # Hybrid replication type for continuous replication. CONTINUOUS_REPLICATION = 2 # New field for reversible OnPrem replication, to be used for data # protection. ONPREM_REPLICATION = 3 # New field for reversible OnPrem replication, to be used for data # protection. REVERSE_ONPREM_REPLICATION = 4 end end |
#replication ⇒ ::String
Returns Required. Desired name for the replication of this volume.
687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 |
# File 'proto_docs/google/cloud/netapp/v1/volume.rb', line 687 class HybridReplicationParameters include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Type of the volume's hybrid replication. module VolumeHybridReplicationType # Unspecified hybrid replication type. VOLUME_HYBRID_REPLICATION_TYPE_UNSPECIFIED = 0 # Hybrid replication type for migration. MIGRATION = 1 # Hybrid replication type for continuous replication. CONTINUOUS_REPLICATION = 2 # New field for reversible OnPrem replication, to be used for data # protection. ONPREM_REPLICATION = 3 # New field for reversible OnPrem replication, to be used for data # protection. REVERSE_ONPREM_REPLICATION = 4 end end |
#replication_schedule ⇒ ::Google::Cloud::NetApp::V1::HybridReplicationSchedule
Returns Optional. Replication Schedule for the replication created.
687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 |
# File 'proto_docs/google/cloud/netapp/v1/volume.rb', line 687 class HybridReplicationParameters include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Type of the volume's hybrid replication. module VolumeHybridReplicationType # Unspecified hybrid replication type. VOLUME_HYBRID_REPLICATION_TYPE_UNSPECIFIED = 0 # Hybrid replication type for migration. MIGRATION = 1 # Hybrid replication type for continuous replication. CONTINUOUS_REPLICATION = 2 # New field for reversible OnPrem replication, to be used for data # protection. ONPREM_REPLICATION = 3 # New field for reversible OnPrem replication, to be used for data # protection. REVERSE_ONPREM_REPLICATION = 4 end end |