Class: Google::Cloud::NetApp::V1::RestoreBackupFilesRequest
- Inherits:
-
Object
- Object
- Google::Cloud::NetApp::V1::RestoreBackupFilesRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/netapp/v1/volume.rb
Overview
RestoreBackupFilesRequest restores files from a backup to a volume.
Instance Attribute Summary collapse
-
#backup ⇒ ::String
Required.
-
#file_list ⇒ ::Array<::String>
Required.
-
#name ⇒ ::String
Required.
-
#restore_destination_path ⇒ ::String
Optional.
Instance Attribute Details
#backup ⇒ ::String
Returns Required. The backup resource name, in the format
projects/{project_id}/locations/{location}/backupVaults/{backup_vault_id}/backups/{backup_id}.
897 898 899 900 |
# File 'proto_docs/google/cloud/netapp/v1/volume.rb', line 897 class RestoreBackupFilesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#file_list ⇒ ::Array<::String>
Returns Required. List of files to be restored, specified by their absolute path in the source volume.
897 898 899 900 |
# File 'proto_docs/google/cloud/netapp/v1/volume.rb', line 897 class RestoreBackupFilesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Required. The volume resource name, in the format
projects/{project_id}/locations/{location}/volumes/{volume_id}.
897 898 899 900 |
# File 'proto_docs/google/cloud/netapp/v1/volume.rb', line 897 class RestoreBackupFilesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#restore_destination_path ⇒ ::String
Returns Optional. Absolute directory path in the destination volume. This is
required if the file_list is provided.
897 898 899 900 |
# File 'proto_docs/google/cloud/netapp/v1/volume.rb', line 897 class RestoreBackupFilesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |