Class: Google::Cloud::NetApp::V1::StoragePool
- Inherits:
-
Object
- Object
- Google::Cloud::NetApp::V1::StoragePool
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/netapp/v1/storage_pool.rb
Overview
StoragePool is a container for volumes with a service level and capacity. Volumes can be created in a pool of sufficient available capacity. StoragePool capacity is what you are billed for.
Defined Under Namespace
Modules: State Classes: LabelsEntry
Instance Attribute Summary collapse
-
#active_directory ⇒ ::String
Optional.
-
#allow_auto_tiering ⇒ ::Boolean
Optional.
-
#available_throughput_mibps ⇒ ::Float
readonly
Output only.
-
#capacity_gib ⇒ ::Integer
Required.
-
#cold_tier_size_used_gib ⇒ ::Integer
readonly
Output only.
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#custom_performance_enabled ⇒ ::Boolean
Optional.
-
#description ⇒ ::String
Optional.
-
#enable_hot_tier_auto_resize ⇒ ::Boolean
Optional.
-
#encryption_type ⇒ ::Google::Cloud::NetApp::V1::EncryptionType
readonly
Output only.
-
#global_access_allowed ⇒ ::Boolean
deprecated
Deprecated.
This field is deprecated and may be removed in the next major version update.
-
#hot_tier_size_gib ⇒ ::Integer
Optional.
-
#hot_tier_size_used_gib ⇒ ::Integer
readonly
Output only.
-
#kms_config ⇒ ::String
Optional.
-
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Optional.
-
#ldap_enabled ⇒ ::Boolean
Optional.
-
#mode ⇒ ::Google::Cloud::NetApp::V1::Mode
Optional.
-
#name ⇒ ::String
Identifier.
-
#network ⇒ ::String
Required.
-
#psa_range ⇒ ::String
Optional.
-
#qos_type ⇒ ::Google::Cloud::NetApp::V1::QosType
Optional.
-
#replica_zone ⇒ ::String
Optional.
-
#satisfies_pzi ⇒ ::Boolean
readonly
Output only.
-
#satisfies_pzs ⇒ ::Boolean
readonly
Output only.
-
#scale_type ⇒ ::Google::Cloud::NetApp::V1::ScaleType
Optional.
-
#service_level ⇒ ::Google::Cloud::NetApp::V1::ServiceLevel
Required.
-
#state ⇒ ::Google::Cloud::NetApp::V1::StoragePool::State
readonly
Output only.
-
#state_details ⇒ ::String
readonly
Output only.
-
#total_iops ⇒ ::Integer
Optional.
-
#total_throughput_mibps ⇒ ::Integer
Optional.
-
#type ⇒ ::Google::Cloud::NetApp::V1::StoragePoolType
Optional.
-
#volume_capacity_gib ⇒ ::Integer
readonly
Output only.
-
#volume_count ⇒ ::Integer
readonly
Output only.
-
#zone ⇒ ::String
Optional.
Instance Attribute Details
#active_directory ⇒ ::String
Returns Optional. Specifies the Active Directory to be used for creating a SMB volume.
252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 |
# File 'proto_docs/google/cloud/netapp/v1/storage_pool.rb', line 252 class StoragePool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The Storage Pool States module State # Unspecified Storage Pool State STATE_UNSPECIFIED = 0 # Storage Pool State is Ready READY = 1 # Storage Pool State is Creating CREATING = 2 # Storage Pool State is Deleting DELETING = 3 # Storage Pool State is Updating UPDATING = 4 # Storage Pool State is Restoring RESTORING = 5 # Storage Pool State is Disabled DISABLED = 6 # Storage Pool State is Error ERROR = 7 end end |
#allow_auto_tiering ⇒ ::Boolean
Returns Optional. True if the storage pool supports Auto Tiering enabled volumes. Default is false. Auto-tiering can be enabled after storage pool creation but it can't be disabled once enabled.
252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 |
# File 'proto_docs/google/cloud/netapp/v1/storage_pool.rb', line 252 class StoragePool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The Storage Pool States module State # Unspecified Storage Pool State STATE_UNSPECIFIED = 0 # Storage Pool State is Ready READY = 1 # Storage Pool State is Creating CREATING = 2 # Storage Pool State is Deleting DELETING = 3 # Storage Pool State is Updating UPDATING = 4 # Storage Pool State is Restoring RESTORING = 5 # Storage Pool State is Disabled DISABLED = 6 # Storage Pool State is Error ERROR = 7 end end |
#available_throughput_mibps ⇒ ::Float (readonly)
Returns Output only. Available throughput of the storage pool (in MiB/s).
252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 |
# File 'proto_docs/google/cloud/netapp/v1/storage_pool.rb', line 252 class StoragePool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The Storage Pool States module State # Unspecified Storage Pool State STATE_UNSPECIFIED = 0 # Storage Pool State is Ready READY = 1 # Storage Pool State is Creating CREATING = 2 # Storage Pool State is Deleting DELETING = 3 # Storage Pool State is Updating UPDATING = 4 # Storage Pool State is Restoring RESTORING = 5 # Storage Pool State is Disabled DISABLED = 6 # Storage Pool State is Error ERROR = 7 end end |
#capacity_gib ⇒ ::Integer
Returns Required. Capacity in GIB of the pool.
252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 |
# File 'proto_docs/google/cloud/netapp/v1/storage_pool.rb', line 252 class StoragePool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The Storage Pool States module State # Unspecified Storage Pool State STATE_UNSPECIFIED = 0 # Storage Pool State is Ready READY = 1 # Storage Pool State is Creating CREATING = 2 # Storage Pool State is Deleting DELETING = 3 # Storage Pool State is Updating UPDATING = 4 # Storage Pool State is Restoring RESTORING = 5 # Storage Pool State is Disabled DISABLED = 6 # Storage Pool State is Error ERROR = 7 end end |
#cold_tier_size_used_gib ⇒ ::Integer (readonly)
Returns Output only. Total cold tier data rounded down to the nearest GiB used by the storage pool.
252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 |
# File 'proto_docs/google/cloud/netapp/v1/storage_pool.rb', line 252 class StoragePool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The Storage Pool States module State # Unspecified Storage Pool State STATE_UNSPECIFIED = 0 # Storage Pool State is Ready READY = 1 # Storage Pool State is Creating CREATING = 2 # Storage Pool State is Deleting DELETING = 3 # Storage Pool State is Updating UPDATING = 4 # Storage Pool State is Restoring RESTORING = 5 # Storage Pool State is Disabled DISABLED = 6 # Storage Pool State is Error ERROR = 7 end end |
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Create time of the storage pool.
252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 |
# File 'proto_docs/google/cloud/netapp/v1/storage_pool.rb', line 252 class StoragePool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The Storage Pool States module State # Unspecified Storage Pool State STATE_UNSPECIFIED = 0 # Storage Pool State is Ready READY = 1 # Storage Pool State is Creating CREATING = 2 # Storage Pool State is Deleting DELETING = 3 # Storage Pool State is Updating UPDATING = 4 # Storage Pool State is Restoring RESTORING = 5 # Storage Pool State is Disabled DISABLED = 6 # Storage Pool State is Error ERROR = 7 end end |
#custom_performance_enabled ⇒ ::Boolean
Returns Optional. True if using Independent Scaling of capacity and performance (Hyperdisk) By default set to false.
252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 |
# File 'proto_docs/google/cloud/netapp/v1/storage_pool.rb', line 252 class StoragePool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The Storage Pool States module State # Unspecified Storage Pool State STATE_UNSPECIFIED = 0 # Storage Pool State is Ready READY = 1 # Storage Pool State is Creating CREATING = 2 # Storage Pool State is Deleting DELETING = 3 # Storage Pool State is Updating UPDATING = 4 # Storage Pool State is Restoring RESTORING = 5 # Storage Pool State is Disabled DISABLED = 6 # Storage Pool State is Error ERROR = 7 end end |
#description ⇒ ::String
Returns Optional. Description of the storage pool.
252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 |
# File 'proto_docs/google/cloud/netapp/v1/storage_pool.rb', line 252 class StoragePool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The Storage Pool States module State # Unspecified Storage Pool State STATE_UNSPECIFIED = 0 # Storage Pool State is Ready READY = 1 # Storage Pool State is Creating CREATING = 2 # Storage Pool State is Deleting DELETING = 3 # Storage Pool State is Updating UPDATING = 4 # Storage Pool State is Restoring RESTORING = 5 # Storage Pool State is Disabled DISABLED = 6 # Storage Pool State is Error ERROR = 7 end end |
#enable_hot_tier_auto_resize ⇒ ::Boolean
Returns Optional. Flag indicating that the hot-tier threshold will be auto-increased by 10% of the hot-tier when it hits 100%. Default is true. The increment will kick in only if the new size after increment is still less than or equal to storage pool size.
252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 |
# File 'proto_docs/google/cloud/netapp/v1/storage_pool.rb', line 252 class StoragePool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The Storage Pool States module State # Unspecified Storage Pool State STATE_UNSPECIFIED = 0 # Storage Pool State is Ready READY = 1 # Storage Pool State is Creating CREATING = 2 # Storage Pool State is Deleting DELETING = 3 # Storage Pool State is Updating UPDATING = 4 # Storage Pool State is Restoring RESTORING = 5 # Storage Pool State is Disabled DISABLED = 6 # Storage Pool State is Error ERROR = 7 end end |
#encryption_type ⇒ ::Google::Cloud::NetApp::V1::EncryptionType (readonly)
Returns Output only. Specifies the current pool encryption key source.
252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 |
# File 'proto_docs/google/cloud/netapp/v1/storage_pool.rb', line 252 class StoragePool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The Storage Pool States module State # Unspecified Storage Pool State STATE_UNSPECIFIED = 0 # Storage Pool State is Ready READY = 1 # Storage Pool State is Creating CREATING = 2 # Storage Pool State is Deleting DELETING = 3 # Storage Pool State is Updating UPDATING = 4 # Storage Pool State is Restoring RESTORING = 5 # Storage Pool State is Disabled DISABLED = 6 # Storage Pool State is Error ERROR = 7 end end |
#global_access_allowed ⇒ ::Boolean
This field is deprecated and may be removed in the next major version update.
Returns Deprecated. Used to allow SO pool to access AD or DNS server from other regions.
252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 |
# File 'proto_docs/google/cloud/netapp/v1/storage_pool.rb', line 252 class StoragePool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The Storage Pool States module State # Unspecified Storage Pool State STATE_UNSPECIFIED = 0 # Storage Pool State is Ready READY = 1 # Storage Pool State is Creating CREATING = 2 # Storage Pool State is Deleting DELETING = 3 # Storage Pool State is Updating UPDATING = 4 # Storage Pool State is Restoring RESTORING = 5 # Storage Pool State is Disabled DISABLED = 6 # Storage Pool State is Error ERROR = 7 end end |
#hot_tier_size_gib ⇒ ::Integer
Returns Optional. Total hot tier capacity for the Storage Pool. It is applicable only to Flex service level. It should be less than the minimum storage pool size and cannot be more than the current storage pool size. It cannot be decreased once set.
252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 |
# File 'proto_docs/google/cloud/netapp/v1/storage_pool.rb', line 252 class StoragePool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The Storage Pool States module State # Unspecified Storage Pool State STATE_UNSPECIFIED = 0 # Storage Pool State is Ready READY = 1 # Storage Pool State is Creating CREATING = 2 # Storage Pool State is Deleting DELETING = 3 # Storage Pool State is Updating UPDATING = 4 # Storage Pool State is Restoring RESTORING = 5 # Storage Pool State is Disabled DISABLED = 6 # Storage Pool State is Error ERROR = 7 end end |
#hot_tier_size_used_gib ⇒ ::Integer (readonly)
Returns Output only. Total hot tier data rounded down to the nearest GiB used by the storage pool.
252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 |
# File 'proto_docs/google/cloud/netapp/v1/storage_pool.rb', line 252 class StoragePool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The Storage Pool States module State # Unspecified Storage Pool State STATE_UNSPECIFIED = 0 # Storage Pool State is Ready READY = 1 # Storage Pool State is Creating CREATING = 2 # Storage Pool State is Deleting DELETING = 3 # Storage Pool State is Updating UPDATING = 4 # Storage Pool State is Restoring RESTORING = 5 # Storage Pool State is Disabled DISABLED = 6 # Storage Pool State is Error ERROR = 7 end end |
#kms_config ⇒ ::String
Returns Optional. Specifies the KMS config to be used for volume encryption.
252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 |
# File 'proto_docs/google/cloud/netapp/v1/storage_pool.rb', line 252 class StoragePool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The Storage Pool States module State # Unspecified Storage Pool State STATE_UNSPECIFIED = 0 # Storage Pool State is Ready READY = 1 # Storage Pool State is Creating CREATING = 2 # Storage Pool State is Deleting DELETING = 3 # Storage Pool State is Updating UPDATING = 4 # Storage Pool State is Restoring RESTORING = 5 # Storage Pool State is Disabled DISABLED = 6 # Storage Pool State is Error ERROR = 7 end end |
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Optional. Labels as key value pairs.
252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 |
# File 'proto_docs/google/cloud/netapp/v1/storage_pool.rb', line 252 class StoragePool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The Storage Pool States module State # Unspecified Storage Pool State STATE_UNSPECIFIED = 0 # Storage Pool State is Ready READY = 1 # Storage Pool State is Creating CREATING = 2 # Storage Pool State is Deleting DELETING = 3 # Storage Pool State is Updating UPDATING = 4 # Storage Pool State is Restoring RESTORING = 5 # Storage Pool State is Disabled DISABLED = 6 # Storage Pool State is Error ERROR = 7 end end |
#ldap_enabled ⇒ ::Boolean
Returns Optional. Flag indicating if the pool is NFS LDAP enabled or not.
252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 |
# File 'proto_docs/google/cloud/netapp/v1/storage_pool.rb', line 252 class StoragePool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The Storage Pool States module State # Unspecified Storage Pool State STATE_UNSPECIFIED = 0 # Storage Pool State is Ready READY = 1 # Storage Pool State is Creating CREATING = 2 # Storage Pool State is Deleting DELETING = 3 # Storage Pool State is Updating UPDATING = 4 # Storage Pool State is Restoring RESTORING = 5 # Storage Pool State is Disabled DISABLED = 6 # Storage Pool State is Error ERROR = 7 end end |
#mode ⇒ ::Google::Cloud::NetApp::V1::Mode
Returns Optional. Mode of the storage pool. This field is used to control whether
the user can perform the ONTAP operations on the storage pool using the
GCNV ONTAP Mode APIs. If not specified during creation, it defaults to
DEFAULT.
252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 |
# File 'proto_docs/google/cloud/netapp/v1/storage_pool.rb', line 252 class StoragePool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The Storage Pool States module State # Unspecified Storage Pool State STATE_UNSPECIFIED = 0 # Storage Pool State is Ready READY = 1 # Storage Pool State is Creating CREATING = 2 # Storage Pool State is Deleting DELETING = 3 # Storage Pool State is Updating UPDATING = 4 # Storage Pool State is Restoring RESTORING = 5 # Storage Pool State is Disabled DISABLED = 6 # Storage Pool State is Error ERROR = 7 end end |
#name ⇒ ::String
Returns Identifier. Name of the storage pool.
252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 |
# File 'proto_docs/google/cloud/netapp/v1/storage_pool.rb', line 252 class StoragePool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The Storage Pool States module State # Unspecified Storage Pool State STATE_UNSPECIFIED = 0 # Storage Pool State is Ready READY = 1 # Storage Pool State is Creating CREATING = 2 # Storage Pool State is Deleting DELETING = 3 # Storage Pool State is Updating UPDATING = 4 # Storage Pool State is Restoring RESTORING = 5 # Storage Pool State is Disabled DISABLED = 6 # Storage Pool State is Error ERROR = 7 end end |
#network ⇒ ::String
Returns Required. VPC Network name. Format: projects/{project}/global/networks/{network}.
252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 |
# File 'proto_docs/google/cloud/netapp/v1/storage_pool.rb', line 252 class StoragePool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The Storage Pool States module State # Unspecified Storage Pool State STATE_UNSPECIFIED = 0 # Storage Pool State is Ready READY = 1 # Storage Pool State is Creating CREATING = 2 # Storage Pool State is Deleting DELETING = 3 # Storage Pool State is Updating UPDATING = 4 # Storage Pool State is Restoring RESTORING = 5 # Storage Pool State is Disabled DISABLED = 6 # Storage Pool State is Error ERROR = 7 end end |
#psa_range ⇒ ::String
Returns Optional. This field is not implemented. The values provided in this field are ignored.
252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 |
# File 'proto_docs/google/cloud/netapp/v1/storage_pool.rb', line 252 class StoragePool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The Storage Pool States module State # Unspecified Storage Pool State STATE_UNSPECIFIED = 0 # Storage Pool State is Ready READY = 1 # Storage Pool State is Creating CREATING = 2 # Storage Pool State is Deleting DELETING = 3 # Storage Pool State is Updating UPDATING = 4 # Storage Pool State is Restoring RESTORING = 5 # Storage Pool State is Disabled DISABLED = 6 # Storage Pool State is Error ERROR = 7 end end |
#qos_type ⇒ ::Google::Cloud::NetApp::V1::QosType
Returns Optional. QoS (Quality of Service) Type of the storage pool.
252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 |
# File 'proto_docs/google/cloud/netapp/v1/storage_pool.rb', line 252 class StoragePool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The Storage Pool States module State # Unspecified Storage Pool State STATE_UNSPECIFIED = 0 # Storage Pool State is Ready READY = 1 # Storage Pool State is Creating CREATING = 2 # Storage Pool State is Deleting DELETING = 3 # Storage Pool State is Updating UPDATING = 4 # Storage Pool State is Restoring RESTORING = 5 # Storage Pool State is Disabled DISABLED = 6 # Storage Pool State is Error ERROR = 7 end end |
#replica_zone ⇒ ::String
Returns Optional. Specifies the replica zone for regional storagePool.
252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 |
# File 'proto_docs/google/cloud/netapp/v1/storage_pool.rb', line 252 class StoragePool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The Storage Pool States module State # Unspecified Storage Pool State STATE_UNSPECIFIED = 0 # Storage Pool State is Ready READY = 1 # Storage Pool State is Creating CREATING = 2 # Storage Pool State is Deleting DELETING = 3 # Storage Pool State is Updating UPDATING = 4 # Storage Pool State is Restoring RESTORING = 5 # Storage Pool State is Disabled DISABLED = 6 # Storage Pool State is Error ERROR = 7 end end |
#satisfies_pzi ⇒ ::Boolean (readonly)
Returns Output only. Reserved for future use.
252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 |
# File 'proto_docs/google/cloud/netapp/v1/storage_pool.rb', line 252 class StoragePool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The Storage Pool States module State # Unspecified Storage Pool State STATE_UNSPECIFIED = 0 # Storage Pool State is Ready READY = 1 # Storage Pool State is Creating CREATING = 2 # Storage Pool State is Deleting DELETING = 3 # Storage Pool State is Updating UPDATING = 4 # Storage Pool State is Restoring RESTORING = 5 # Storage Pool State is Disabled DISABLED = 6 # Storage Pool State is Error ERROR = 7 end end |
#satisfies_pzs ⇒ ::Boolean (readonly)
Returns Output only. Reserved for future use.
252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 |
# File 'proto_docs/google/cloud/netapp/v1/storage_pool.rb', line 252 class StoragePool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The Storage Pool States module State # Unspecified Storage Pool State STATE_UNSPECIFIED = 0 # Storage Pool State is Ready READY = 1 # Storage Pool State is Creating CREATING = 2 # Storage Pool State is Deleting DELETING = 3 # Storage Pool State is Updating UPDATING = 4 # Storage Pool State is Restoring RESTORING = 5 # Storage Pool State is Disabled DISABLED = 6 # Storage Pool State is Error ERROR = 7 end end |
#scale_type ⇒ ::Google::Cloud::NetApp::V1::ScaleType
Returns Optional. The scale type of the storage pool. Defaults to
SCALE_TYPE_DEFAULT if not specified.
252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 |
# File 'proto_docs/google/cloud/netapp/v1/storage_pool.rb', line 252 class StoragePool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The Storage Pool States module State # Unspecified Storage Pool State STATE_UNSPECIFIED = 0 # Storage Pool State is Ready READY = 1 # Storage Pool State is Creating CREATING = 2 # Storage Pool State is Deleting DELETING = 3 # Storage Pool State is Updating UPDATING = 4 # Storage Pool State is Restoring RESTORING = 5 # Storage Pool State is Disabled DISABLED = 6 # Storage Pool State is Error ERROR = 7 end end |
#service_level ⇒ ::Google::Cloud::NetApp::V1::ServiceLevel
Returns Required. Service level of the storage pool.
252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 |
# File 'proto_docs/google/cloud/netapp/v1/storage_pool.rb', line 252 class StoragePool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The Storage Pool States module State # Unspecified Storage Pool State STATE_UNSPECIFIED = 0 # Storage Pool State is Ready READY = 1 # Storage Pool State is Creating CREATING = 2 # Storage Pool State is Deleting DELETING = 3 # Storage Pool State is Updating UPDATING = 4 # Storage Pool State is Restoring RESTORING = 5 # Storage Pool State is Disabled DISABLED = 6 # Storage Pool State is Error ERROR = 7 end end |
#state ⇒ ::Google::Cloud::NetApp::V1::StoragePool::State (readonly)
Returns Output only. State of the storage pool.
252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 |
# File 'proto_docs/google/cloud/netapp/v1/storage_pool.rb', line 252 class StoragePool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The Storage Pool States module State # Unspecified Storage Pool State STATE_UNSPECIFIED = 0 # Storage Pool State is Ready READY = 1 # Storage Pool State is Creating CREATING = 2 # Storage Pool State is Deleting DELETING = 3 # Storage Pool State is Updating UPDATING = 4 # Storage Pool State is Restoring RESTORING = 5 # Storage Pool State is Disabled DISABLED = 6 # Storage Pool State is Error ERROR = 7 end end |
#state_details ⇒ ::String (readonly)
Returns Output only. State details of the storage pool.
252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 |
# File 'proto_docs/google/cloud/netapp/v1/storage_pool.rb', line 252 class StoragePool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The Storage Pool States module State # Unspecified Storage Pool State STATE_UNSPECIFIED = 0 # Storage Pool State is Ready READY = 1 # Storage Pool State is Creating CREATING = 2 # Storage Pool State is Deleting DELETING = 3 # Storage Pool State is Updating UPDATING = 4 # Storage Pool State is Restoring RESTORING = 5 # Storage Pool State is Disabled DISABLED = 6 # Storage Pool State is Error ERROR = 7 end end |
#total_iops ⇒ ::Integer
Returns Optional. Custom Performance Total IOPS of the pool if not provided, it will be calculated based on the total_throughput_mibps.
252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 |
# File 'proto_docs/google/cloud/netapp/v1/storage_pool.rb', line 252 class StoragePool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The Storage Pool States module State # Unspecified Storage Pool State STATE_UNSPECIFIED = 0 # Storage Pool State is Ready READY = 1 # Storage Pool State is Creating CREATING = 2 # Storage Pool State is Deleting DELETING = 3 # Storage Pool State is Updating UPDATING = 4 # Storage Pool State is Restoring RESTORING = 5 # Storage Pool State is Disabled DISABLED = 6 # Storage Pool State is Error ERROR = 7 end end |
#total_throughput_mibps ⇒ ::Integer
Returns Optional. Custom Performance Total Throughput of the pool (in MiBps).
252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 |
# File 'proto_docs/google/cloud/netapp/v1/storage_pool.rb', line 252 class StoragePool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The Storage Pool States module State # Unspecified Storage Pool State STATE_UNSPECIFIED = 0 # Storage Pool State is Ready READY = 1 # Storage Pool State is Creating CREATING = 2 # Storage Pool State is Deleting DELETING = 3 # Storage Pool State is Updating UPDATING = 4 # Storage Pool State is Restoring RESTORING = 5 # Storage Pool State is Disabled DISABLED = 6 # Storage Pool State is Error ERROR = 7 end end |
#type ⇒ ::Google::Cloud::NetApp::V1::StoragePoolType
Returns Optional. Type of the storage pool. This field is used to control whether
the pool supports FILE based volumes only or UNIFIED (both FILE and
BLOCK) volumes. If not specified during creation, it defaults to FILE.
252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 |
# File 'proto_docs/google/cloud/netapp/v1/storage_pool.rb', line 252 class StoragePool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The Storage Pool States module State # Unspecified Storage Pool State STATE_UNSPECIFIED = 0 # Storage Pool State is Ready READY = 1 # Storage Pool State is Creating CREATING = 2 # Storage Pool State is Deleting DELETING = 3 # Storage Pool State is Updating UPDATING = 4 # Storage Pool State is Restoring RESTORING = 5 # Storage Pool State is Disabled DISABLED = 6 # Storage Pool State is Error ERROR = 7 end end |
#volume_capacity_gib ⇒ ::Integer (readonly)
Returns Output only. Allocated size of all volumes in GIB in the storage pool.
252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 |
# File 'proto_docs/google/cloud/netapp/v1/storage_pool.rb', line 252 class StoragePool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The Storage Pool States module State # Unspecified Storage Pool State STATE_UNSPECIFIED = 0 # Storage Pool State is Ready READY = 1 # Storage Pool State is Creating CREATING = 2 # Storage Pool State is Deleting DELETING = 3 # Storage Pool State is Updating UPDATING = 4 # Storage Pool State is Restoring RESTORING = 5 # Storage Pool State is Disabled DISABLED = 6 # Storage Pool State is Error ERROR = 7 end end |
#volume_count ⇒ ::Integer (readonly)
Returns Output only. Volume count of the storage pool.
252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 |
# File 'proto_docs/google/cloud/netapp/v1/storage_pool.rb', line 252 class StoragePool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The Storage Pool States module State # Unspecified Storage Pool State STATE_UNSPECIFIED = 0 # Storage Pool State is Ready READY = 1 # Storage Pool State is Creating CREATING = 2 # Storage Pool State is Deleting DELETING = 3 # Storage Pool State is Updating UPDATING = 4 # Storage Pool State is Restoring RESTORING = 5 # Storage Pool State is Disabled DISABLED = 6 # Storage Pool State is Error ERROR = 7 end end |
#zone ⇒ ::String
Returns Optional. Specifies the active zone for regional storagePool.
252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 |
# File 'proto_docs/google/cloud/netapp/v1/storage_pool.rb', line 252 class StoragePool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The Storage Pool States module State # Unspecified Storage Pool State STATE_UNSPECIFIED = 0 # Storage Pool State is Ready READY = 1 # Storage Pool State is Creating CREATING = 2 # Storage Pool State is Deleting DELETING = 3 # Storage Pool State is Updating UPDATING = 4 # Storage Pool State is Restoring RESTORING = 5 # Storage Pool State is Disabled DISABLED = 6 # Storage Pool State is Error ERROR = 7 end end |