Class: Google::Cloud::NetApp::V1::TieringPolicy
- Inherits:
-
Object
- Object
- Google::Cloud::NetApp::V1::TieringPolicy
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/netapp/v1/volume.rb
Overview
Defines tiering policy for the volume.
Defined Under Namespace
Modules: TierAction
Instance Attribute Summary collapse
-
#cooling_threshold_days ⇒ ::Integer
Optional.
-
#hot_tier_bypass_mode_enabled ⇒ ::Boolean
Optional.
-
#tier_action ⇒ ::Google::Cloud::NetApp::V1::TieringPolicy::TierAction
Optional.
Instance Attribute Details
#cooling_threshold_days ⇒ ::Integer
Returns Optional. Time in days to mark the volume's data block as cold and make it eligible for tiering, can be range from 2-183. Default is 31.
631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 |
# File 'proto_docs/google/cloud/netapp/v1/volume.rb', line 631 class TieringPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Tier action for the volume. module TierAction # Unspecified. TIER_ACTION_UNSPECIFIED = 0 # When tiering is enabled, new cold data will be tiered. ENABLED = 1 # When paused, tiering won't be performed on new data. Existing data stays # tiered until accessed. PAUSED = 2 end end |
#hot_tier_bypass_mode_enabled ⇒ ::Boolean
Returns Optional. Flag indicating that the hot tier bypass mode is enabled. Default is false. This is only applicable to Flex service level.
631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 |
# File 'proto_docs/google/cloud/netapp/v1/volume.rb', line 631 class TieringPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Tier action for the volume. module TierAction # Unspecified. TIER_ACTION_UNSPECIFIED = 0 # When tiering is enabled, new cold data will be tiered. ENABLED = 1 # When paused, tiering won't be performed on new data. Existing data stays # tiered until accessed. PAUSED = 2 end end |
#tier_action ⇒ ::Google::Cloud::NetApp::V1::TieringPolicy::TierAction
Returns Optional. Flag indicating if the volume has tiering policy enable/pause. Default is PAUSED.
631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 |
# File 'proto_docs/google/cloud/netapp/v1/volume.rb', line 631 class TieringPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Tier action for the volume. module TierAction # Unspecified. TIER_ACTION_UNSPECIFIED = 0 # When tiering is enabled, new cold data will be tiered. ENABLED = 1 # When paused, tiering won't be performed on new data. Existing data stays # tiered until accessed. PAUSED = 2 end end |